---
layout: base
title: Official Merchandise
navbar_active: store
view_class: v-store
relative_path: ../
---
{% capture jumbotron_h1 %}<i class="fa fa-shopping-cart fa-lg valign-baseline" aria-hidden="true"></i>&nbsp; Awesome Swag{% endcapture %}
{% capture jumbotron_p %}Show your love &amp; support of Font Awesome with official merchandise!{% endcapture %}

{% include jumbotron.html %}

<div class="content-underlay"></div>

<div class="container">
  <div class="row">
    <div class="col-sm-6 col-lg-4">
      {% include products/fa-ther-tee.html %}
    </div>
    <div class="col-sm-6 col-lg-4">
      {% include products/space-shuttle-tee.html %}
    </div>
    <div class="col-sm-6 col-lg-4">
      {% include products/rock-paper-scissors-lizard-spock-tee.html %}
    </div>
    <div class="col-sm-6 col-lg-4">
      {% include products/white-logo-tee.html %}
    </div>
    <div class="col-sm-6 col-lg-4">
      {% include products/camera-retro-tee.html %}
    </div>
    <div class="col-sm-6 col-lg-4">
      {% include products/old-skool-tee.html %}
    </div>
    <div class="col-sm-6 col-lg-4">
      {% include products/classics-tee.html %}
    </div>
    <div class="col-sm-6 col-lg-4">
      {% include products/green-logo-tee.html %}
    </div>
    <div class="col-sm-12 col-lg-4">
      {% include products/cta-suggestions.html %}
    </div>
  </div>

  <hr>

  <div class="row">
    <div class="col-sm-12 col-md-6">
      <h4>About Font Awesome Products</h4>
      <p>
        There might be times where you want to insert a bit of Font Awesome in the real world. That's why we're trying out some schwag. We hope you enjoy our icons and their fun spirit out in the wild and appreciate the support you're showing and giving by doing so. <strong>You're putting the Awesome in Font Awesome!</strong>
      </p>
    </div>

    <div class="col-sm-12 col-md-6">
      <h4>Shipping, Tracking, &amp; Refunding Orders</h4>
      <p>
        All of our products are managed through <a href="http://www.amazon.com/s/ref=w_bl_sl_s_ap_web_7141123011?ie=UTF8&node=7141123011&field-brandtextbin=Font+Awesome"><i class="fas fas-amazon"></i> Amazon</a>. Shipping rates and schedules are managed through their storefront. You'll be able to track your placed orders and contact Amazon's responsive support about refunds, issues, or questions. Ratings and feedback are always welcome either on the product page or <a href="mailto:suggestions@fortawesome.com">directly to us</a>.
      </p>
    </div>
  </div>
</div>
