---
layout: base
title: Your Embed Code is on the way!
relative_path: ../../
---

<div class="container">
  <div class="row margin-top-xl">
    <div class="col-lg-7">
      <div class="well well-lg margin-bottom-xl">
        <h1 class="page-header text-success">
          <i class="fa fa-check"></i>
          Great Success!
        </h1>

        <p class="lead">
          <strong>Your embed code is on its way.</strong>
        </p>

        <p>
          We just sent you an email with your new Font Awesome CDN embed code and instructions for what to do next!
        </p>

        <p>
          If you don't see the email (sent by "Font Awesome") in your inbox, maybe check your spam folder first. Also, make sure you haven't previously unsubscribed. Still nothing? <a href="{{ page.relative_path }}get-started/#get-started-cdn">Try again</a> or <a href="https://cdn.fontawesome.com/help">get some help</a>.
        </p>
      </div>
    </div>

    <div class="col-lg-4 col-lg-offset-1">

      <h2 class="sr-only">Next Steps</h2>

      <ol class="list-unstyled gg gg-top">
        <li class="gg-row">
          <div class="gg-col p-xs-r-md">
            <i class="fa fa-envelope fa-2x margin-right-lg text-muted"></i>
          </div>
          <div class="gg-col">
            <h3 class="text-lg text-muted">Check your email</h3>

            <p>
              Your embed code should be waiting there for you. From there you can also register a Font Awesome CDN account to help you manage your icons even more easily.
            </p>

            <hr class="hr-lg m-xs-y-lg">
          </div>
        </li>

        <li class="gg-row">
          <div class="gg-col p-xs-r-md">
            <i class="fa fa-flag-checkered fa-2x margin-right-lg text-muted"></i>
          </div>
          <div class="gg-col">
            <h3 class="text-lg text-muted">Get ready to use Font Awesome</h3>

            <p>
              While you're waiting, dive into how to use Font Awesome. You'll want to add your embed code within the <code>&lt;head&gt;</code> of each template or page that you want to use Font Awesome on. Then, check out the <a href="{{ page.relative_path }}icons/">Font Awesome icons</a> and <a href="{{ page.relative_path }}examples/">examples</a> to learn how drop icons right into your UI.
            </p>
          </div>
        </li>
      </ol>
    </div>
  </div>
</div>
