@media (min-width: @screen-sm) {
  .signup-input {
    padding-right: 0;
    input {
      border-top-right-radius: 0;
      border-bottom-right-radius: 0;
      border-right-width: 0;
    }
  }
  .signup-button {
    padding-left: 0;
    .btn {
      border-top-left-radius: 0;
      border-bottom-left-radius: 0;
    }
  }
}
