<?php
/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 */

session_start();

if (isset($_POST['s_ajax_call']) && ($_POST['s_ajax_call'] == $_SESSION['validate_s_access']) && isset($_POST['currentextension']) && $_POST['currentextension'] != '' &&
    isset($_POST['currentchatpubkey']) && $_POST['currentchatpubkey'] != '') {

       $sipusersendrec = $_POST['currentextension'];
       $chatPubKey = $_POST['currentchatpubkey'];

       // Create the directories if they don't exist
       if (!is_dir('textchat')) {
            mkdir('textchat', 0700);
       }

       if (!is_dir('textchat/' . $sipusersendrec)) {
            mkdir('textchat/' . $sipusersendrec, 0700);
       }

       // Save the RSA public key
       if ($sipusersendrec != '') {

           $savePubKey = file_put_contents('textchat/' . $sipusersendrec . '/rsa_1024_pub.pem', $chatPubKey);
           chmod('textchat/' . $sipusersendrec . '/rsa_1024_pub.pem', 0600);
           $messageres = 'success';

       } else { 
           $messageres = 'failure';
       }

       $generateresp = ['messageres' => $messageres];

       echo json_encode($generateresp);

} else {
    header("Location: roundpin-login.php");
}

?>
