<?php
/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 */

session_start();
unset($_SESSION['loggedtoroundpin']);
unset($_SESSION['loginname']);
session_destroy();
header("Location: roundpin-login.php");
exit();

?>
