/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 *
 *  This is a modified version of the original file "style.css"
 *  released under the MIT License and first modified in 2020.
 *  The copyright notice for the original content follows:
 *
 *  Copyright (c) 2019 by Daniel Zawadzki (https://codepen.io/danzawadzki/pen/EgqKRr)
 */

/* BASIC */

body {
  background-image: url('../images/loginbackground-small.jpg');
  background-repeat: repeat;
  font-family: Inter, sans-serif;
  height: 100vh;
}

a {
  color: #92badd;
  display: inline-block;
  text-decoration: none;
  font-weight: 600;
}

#forgotpass {
  color: #92badd;
  display: inline-block;
  text-decoration: none;
  font-weight: 500;
  cursor: pointer;
}

#forgotpass:hover {
  color: #0d0d0d;
}

h2 {
  text-align: center;
  font-size: 17px;
  font-weight: 800;
  text-transform: uppercase;
  display:inline-block;
  margin: 40px 8px 10px 8px; 
  color: #cccccc;
}

/* STRUCTURE */

.wrapper {
  display: flex;
  align-items: center;
  flex-direction: column; 
  justify-content: center;
  width: 100%;
  min-height: 100%;
  padding: 20px;
}

#formContent {
  -webkit-border-radius: 10px 10px 10px 10px;
  border-radius: 10px 10px 10px 10px;
  background: #fff;
  width: 90%;
  max-width: 450px;
  position: relative;
  padding: 0px;
  -webkit-box-shadow: 0 30px 60px 0 rgba(0,0,0,0.3);
  box-shadow: 0 30px 60px 0 rgba(0,0,0,0.3);
  text-align: center;
  margin-left: auto;
  margin-right: auto;
}

#formFooter {
  background-color: #f6f6f6;
  border-top: 1px solid #dce8f1;
  padding: 25px;
  text-align: center;
  -webkit-border-radius: 0 0 10px 10px;
  border-radius: 0 0 10px 10px;
}

/* TABS */

h2.inactive {
  color: #cccccc;
}

h2.active {
  color: #0d0d0d;
}

/* FORM TYPOGRAPHY*/

input[type=button], input[type=submit], input[type=reset]  {
  display: inline-block;
  background-color: #4d8ad6;
  border: none;
  font-family: Inter, sans-serif;
  color: white;
  text-align: center;
  text-decoration: none;
  text-transform: uppercase;
  font-size: 15px;
  font-weight: 600;
  padding: 15px 80px;
  -webkit-box-shadow: 0 10px 30px 0 rgba(95,186,233,0.4);
  box-shadow: 0 10px 30px 0 rgba(95,186,233,0.4);
  -webkit-border-radius: 5px 5px 5px 5px;
  border-radius: 5px 5px 5px 5px;
  margin: 5px 20px 40px 20px;
}

input[type=button]:hover, input[type=submit]:hover, input[type=reset]:hover  {
  background-color: #4179bf;
  cursor: pointer;
}

input[type=button]:active, input[type=submit]:active, input[type=reset]:active  {
  -moz-transform: scale(0.95);
  -webkit-transform: scale(0.95);
  -o-transform: scale(0.95);
  -ms-transform: scale(0.95);
  transform: scale(0.95);
}

input[type=text] {
  background-color: #f6f6f6;
  border: none;
  color: #0d0d0d;
  padding: 15px 32px;
  font-family: Inter, sans-serif;
  font-size: 17px;
  text-align: center;
  text-decoration: none;
  display: inline-block;
  margin: 5px;
  width: 85%;
  border: 2px solid #f6f6f6;
  -webkit-transition: all 0.5s ease-in-out;
  -moz-transition: all 0.5s ease-in-out;
  -ms-transition: all 0.5s ease-in-out;
  -o-transition: all 0.5s ease-in-out;
  transition: all 0.5s ease-in-out;
  -webkit-border-radius: 5px 5px 5px 5px;
  border-radius: 5px 5px 5px 5px;
}

input[type=text]:focus {
  background-color: #fff;
}

input[type=text]:placeholder {
  color: #cccccc;
}

#selectrole {
  display: block;
  background-color: #f6f6f6;
  border: none;
  color: #7c7c7c;
  text-align: center;
  text-decoration: none;
  font-size: 16px;
  margin-top: 6px;
  margin-bottom: 7px;
  margin-left: auto;
  margin-right: auto;
  width: 85%;
  height: 50px;
  border: 2px solid #f6f6f6;
  -webkit-transition: all 0.5s ease-in-out;
  -moz-transition: all 0.5s ease-in-out;
  -ms-transition: all 0.5s ease-in-out;
  -o-transition: all 0.5s ease-in-out;
  transition: all 0.5s ease-in-out;
  -webkit-border-radius: 5px 5px 5px 5px;
  border-radius: 5px 5px 5px 5px;
  text-align-last: center;
}

#selectrole:focus {
  color: #0d0d0d;
  background-color: #fff;
  border-bottom: 2px solid #5fbae9;
}

#selectrole:active {
  color: #0d0d0d;
  background-color: #fff;
  border-bottom: 2px solid #5fbae9;
}

.selectoption {
  display: block;
  background-color: #f6f6f6;
  border: none;
  color: #0d0d0d;
  padding: 15px 32px;
  text-align: center;
  text-decoration: none;
  font-size: 16px;
  margin-left: auto;
  margin-right: auto;
  width: 85%;
  border: 2px solid #f6f6f6;
  -webkit-transition: all 0.5s ease-in-out;
  -moz-transition: all 0.5s ease-in-out;
  -ms-transition: all 0.5s ease-in-out;
  -o-transition: all 0.5s ease-in-out;
  transition: all 0.5s ease-in-out;
  -webkit-border-radius: 5px 5px 5px 5px;
  border-radius: 5px 5px 5px 5px;
}

input[type=password] {
  background-color: #f6f6f6;
  border: none;
  color: #0d0d0d;
  padding: 15px 32px;
  font-family: Inter, sans-serif;
  font-size: 12px;
  text-align: center;
  text-decoration: none;
  display: inline-block;
  margin: 5px;
  width: 85%;
  border: 2px solid #f6f6f6;
  -webkit-transition: all 0.5s ease-in-out;
  -moz-transition: all 0.5s ease-in-out;
  -ms-transition: all 0.5s ease-in-out;
  -o-transition: all 0.5s ease-in-out;
  transition: all 0.5s ease-in-out;
  -webkit-border-radius: 5px 5px 5px 5px;
  border-radius: 5px 5px 5px 5px;
}

input[type=password]:focus {
  background-color: #fff;
}

input[type=password]:placeholder {
  color: #cccccc;
}

/* ANIMATIONS */

/* Simple CSS3 Fade-in-down Animation */
.fadeInDown {
  -webkit-animation-name: fadeInDown;
  animation-name: fadeInDown;
  -webkit-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
}

@-webkit-keyframes fadeInDown {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
  }
  100% {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

@keyframes fadeInDown {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
  }
  100% {
    opacity: 1;
    -webkit-transform: none;
    transform: none;
  }
}

/* Simple CSS3 Fade-in Animation */
@-webkit-keyframes fadeIn { from { opacity:0; } to { opacity:1; } }
@-moz-keyframes fadeIn { from { opacity:0; } to { opacity:1; } }
@keyframes fadeIn { from { opacity:0; } to { opacity:1; } }

.fadeIn {
  opacity:0;
  -webkit-animation:fadeIn ease-in 0.8s;
  -moz-animation:fadeIn ease-in 0.8s;
  animation:fadeIn ease-in 0.8s;

  -webkit-animation-fill-mode:forwards;
  -moz-animation-fill-mode:forwards;
  animation-fill-mode:forwards;

  -webkit-animation-duration:0.5s;
  -moz-animation-duration:0.5s;
  animation-duration:0.5s;
}

.fadeIn.first {
  -webkit-animation-delay: 0.2s;
  -moz-animation-delay: 0.2s;
  animation-delay: 0.2s;
  max-height: 300px;
  
}

.fadeIn.second {
  -webkit-animation-delay: 0.2s;
  -moz-animation-delay: 0.2s;
  animation-delay: 0.2s;
}

.fadeIn.third {
  -webkit-animation-delay: 0.2s;
  -moz-animation-delay: 0.2s;
  animation-delay: 0.2s;
}

.fadeIn.fourth {
  -webkit-animation-delay: 0.2s;
  -moz-animation-delay: 0.2s;
  animation-delay: 0.2s;
}

.fadeIn.fifth {
  -webkit-animation-delay: 0.2s;
  -moz-animation-delay: 0.2s;
  animation-delay: 0.2s;
}


/* Simple CSS3 Fade-in Animation */

.underlineHover:after {
  display: block;
  width: 0;
  transition: width 0.2s;
}

.underlineHover:hover {
  color: #0d0d0d;
}

/* OTHERS */

*:focus {
    outline: none;
} 

@media screen and (min-width: 601px) {
  #login-logo {
    position: relative;
    margin-top: 35px;
    margin-bottom: 7px;
  }
}

@media only screen and (max-width: 600px) {
  #login-logo {
    position: relative;
    margin-top: 35px;
    margin-bottom: 7px;
    max-width: 186px;
  }

  #signinbutton {
    max-width: 180px !important;
    padding: 15px;
    font-size: 12px;
  }

  #signupbutton {
    max-width: 180px !important;
    padding: 15px;
    font-size: 12px;
  }

  #forgotpassbutton {
    max-width: 180px !important;
    padding: 15px;
    white-space: normal;
    font-size: 12px;
  }

  #emailforgotpass {
    font-size: 13px; 
  }

  #emailaddress, #login, #password, #selectrole {
    font-size: 12px;
  }

  html {
     background: url("../../images/loginbackground.jpg");
     background-repeat: no-repeat;
     background-size: 100% 180%;
  }
}

* {
  box-sizing: border-box;
}

#signintab, #signuptab {
  font-family: Inter, sans-serif;
  font-size: 16px;
  font-weight: 600;
}

#forgotpass {
  font-family: Inter Semi, sans-serif;
  font-size: 16px;
}

#signintab:hover {
  cursor: pointer;
}

#signuptab:hover {
  cursor: pointer;
}

#submitmessage {
  display: block;
  padding: 10px 30px 12px 30px;
  font-size: 17px;
}

#usernameLabel, #passwordLabel, #emailaddressLabel, #regusernameLabel, #regpasswordLabel, #regpasswordrepLabel, #emailaddressfgtLabel {
  display: none;
  position: relative;
  margin: auto;
  text-align: center;
  top: 22px;
  font-size: 14px;
  color: #7c7c7c;
  opacity: 0;
}

.fadeInSpec {
  opacity:0;
  -webkit-animation:fadeIn ease-in 0.2s;
  -moz-animation:fadeIn ease-in 0.2s;
  animation:fadeIn ease-in 0.2s;

  -webkit-animation-fill-mode:forwards;
  -moz-animation-fill-mode:forwards;
  animation-fill-mode:forwards;

  -webkit-animation-duration:0.2s;
  -moz-animation-duration:0.2s;
  animation-duration:0.2s;
}

/* Placeholder styling */
*::-webkit-input-placeholder {
    font-size: 16px;
}
*:-moz-placeholder {
    /* FF 4-18 */
    font-size: 16px;
}
*::-moz-placeholder {
    /* FF 19+ */
    font-size: 16px;
}
*:-ms-input-placeholder {
    /* IE 10+ */
    font-size: 16px;
}
*::-ms-input-placeholder {
    /* Microsoft Edge */
    font-size: 16px;
}
*::placeholder {
    /* modern browser */
    font-size: 16px;
}