/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 */

    body {
       background-color: #F5F5F5;
       padding: 20px;
    }

    #mainarea {
       display: block;
       margin: auto;
       background-color: #e9f4fc;
       padding: 30px;
       max-width: 660px;
       font-size: 18px;
       -webkit-box-shadow: 3px 5px 32px -4px rgba(0,0,0,0.75);
       -moz-box-shadow: 3px 5px 32px -4px rgba(0,0,0,0.75);
       box-shadow: 3px 5px 32px -4px rgba(0,0,0,0.75);
       border-radius: 0px;
    }

    .logosetuppage {
       display: block;
       margin: auto
    }

    .setupStage {
       display: block;
       margin: auto;
       padding-bottom: 70px
    }

    .fieldlabels {
       display: block;
       margin: 0px 0px -14px 0px;
       text-align: center;
       font-size: 17px;
       font-weight: 600;
    }

    .textinput {
       display: block;
       margin: auto;
       height: 35px;
       width: 330px;
       font-size: 17px;
       padding: 0px 7px 0px 7px;
       outline: none !important;
       border-radius: 5px 5px 5px 5px;
       -moz-border-radius: 5px 5px 5px 5px;
       -webkit-border-radius: 5px 5px 5px 5px;
       border: 0px solid #000000;
      -webkit-box-shadow: 3px 4px 12px -3px rgba(0,0,0,0.75);
      -moz-box-shadow: 3px 4px 12px -3px rgba(0,0,0,0.75);
      box-shadow: 3px 4px 12px -3px rgba(0,0,0,0.75);
    }

    #createconfigbttn, #submitadminbttn {
       display: block;
       margin: auto;
       background-color: #6290CC;
       color: #FFFFFF;
       font-weight: bold;
       padding: 13px;
       font-size: 16px;
       border-radius: 5px 5px 5px 5px;
       -moz-border-radius: 5px 5px 5px 5px;
       -webkit-border-radius: 5px 5px 5px 5px;
       border: 0px solid #000000;
    }

    #createconfigbttn:hover, #submitadminbttn:hover {
      cursor: pointer;
      background-color: #5279AC;
    }

    #createconfigbttn:active, #submitadminbttn:active {
      cursor: pointer;
      background-color: #416493;
    }
