<ul class="margin-bottom-none padding-left-lg">
  <li>All brand icons are trademarks of their respective owners.</li>
  <li>The use of these trademarks does not indicate endorsement of the trademark holder by Font Awesome, nor vice versa.</li>
  <li>Brand icons should only be used to represent the company or product to which they refer.</li>
  <li class="strong">Please do not use brand logos for any purpose except to represent that particular brand or service.</li>
</ul>
