<section id="project-milestones">
  <h2 class="page-header">Project Milestones</h2>
  <p>
    Want to keep up with what's planned for Font Awesome? Check out our
    <a href="{{ site.fontawesome.github.url }}/milestones">milestones</a> on the GitHub project.
  </p>
</section>
