/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 *
 *  The "Inter" font is licensed under the SIL Open Font License,
 *  Version 1.1. (available at: https://scripts.sil.org/cms/scripts/page.php?item_id=OFL_web). 
 *  The copyright notice for the "Inter" font follows:
 *
 *  Copyright (c) 2016-2020 The Inter Project Authors.
 *  "Inter" is trademark of Rasmus Andersson.
 *  https://github.com/rsms/inter
 *
 */

/* Latin */
@font-face {
    font-family: 'Inter';
    src: url('../fonts/inter/Inter-Bold.woff2') format('woff2'),
         url('../fonts/inter/Inter-Bold.woff') format('woff');
    font-weight: 700;
    font-style: normal;
}

@font-face {
    font-family: 'Inter';
    src: url('../fonts/inter/Inter-BoldItalic.woff2') format('woff2'),
         url('../fonts/inter/Inter-BoldItalic.woff') format('woff');
    font-weight: 700;
    font-style: italic;
}

@font-face {
    font-family: 'Inter';
    src: url('../fonts/inter/Inter-MediumItalic.woff2') format('woff2'),
         url('../fonts/inter/Inter-MediumItalic.woff') format('woff');
    font-weight: 500;
    font-style: italic;
}

@font-face {
    font-family: 'Inter';
    src: url('../fonts/inter/Inter-SemiBold.woff2') format('woff2'),
         url('../fonts/inter/Inter-SemiBold.woff') format('woff');
    font-weight: 600;
    font-style: normal;
}

@font-face {
    font-family: 'Inter';
    src: url('../fonts/inter/Inter-Regular.woff2') format('woff2'),
         url('../fonts/inter/Inter-Regular.woff') format('woff');
    font-weight: 400;
    font-style: normal;
}

@font-face {
    font-family: 'Inter';
    src: url('../fonts/inter/Inter-SemiBoldItalic.woff2') format('woff2'),
         url('../fonts/inter/Inter-SemiBoldItalic.woff') format('woff');
    font-weight: 600;
    font-style: italic;
}

@font-face {
    font-family: 'Inter';
    src: url('../fonts/inter/Inter-Italic.woff2') format('woff2'),
         url('../fonts/inter/Inter-Italic.woff') format('woff');
    font-weight: 400;
    font-style: italic;
}

@font-face {
    font-family: 'Inter';
    src: url('../fonts/inter/Inter-Medium.woff2') format('woff2'),
         url('../fonts/inter/Inter-Medium.woff') format('woff');
    font-weight: 500;
    font-style: normal;
}
