/**
 * Copyright (C) 2021  Double Bastion LLC
 *
 * This file is part of Roundpin, which is licensed under the
 * GNU Affero General Public License Version 3.0. The license terms
 * are detailed in the "LICENSE.txt" file located in the root directory.
 *
 * This is a modified version of the original file "style.css",
 * first modified in 2021. The copyright notice for the original
 * content follows:


 * Copyright (c) 2013, PlanIt Works BV
 * http://www.tweego.nl
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#jg_popup_overlay{display:none; position:fixed; width:100%; height:100%; top:0; left:0; z-index:2147483645}
#jg_popup_inner{display:none; top:0; left:0; position:absolute; z-index:2147483646}
#jg_popup_table.jg_popup_basic{background:none; border:0; border-collapse:collapse; float:none; height:auto; margin:0; padding:0; width:auto; z-index:auto; display:block}
#jg_popup_table.jg_popup_basic td{border:0; height:auto; margin:0; padding:0; text-align:left; vertical-align:top; width:auto; z-index:auto}
#jg_popup_table.jg_popup_basic #jg_popup_tl{width:10px; height:10px; background:#fff}
#jg_popup_table.jg_popup_basic #jg_popup_title
{ 
    line-height:normal; height:7px; background:#fff; text-decoration:none; text-indent:0; 
	text-transform:none; color:#999; word-spacing:normal; white-space:nowrap; font-family:Arial, Sans-Serif; 
	font-size:11px; font-style:normal; font-variant:normal; font-weight:normal; padding:3px 0 0 0
}
#jg_popup_table.jg_popup_basic #jg_popup_title.jg_popup_draggable{cursor:move}
#jg_popup_table.jg_popup_basic #jg_popup_tr{width:10px; height:10px; background:#fff}
#jg_popup_table.jg_popup_basic #jg_popup_l{width:10px; background:#fff}
#jg_popup_table.jg_popup_basic #jg_popup_content{background:#fff}
#jg_popup_table.jg_popup_basic #jg_popup_loader{position:absolute; width:100%; left:0; top:0; visibility:hidden}
#jg_popup_table.jg_popup_basic #jg_popup_loader div{width:32px; height:32px; background:url(../images/loader.gif) no-repeat; margin:0 auto}
#jg_popup_table.jg_popup_basic #jg_popup_r{width:10px; background:#fff}
#jg_popup_table.jg_popup_basic #jg_popup_bl{width:10px; height:10px; background:#fff}
#jg_popup_table.jg_popup_basic #jg_popup_b{height:10px; background:#fff}
#jg_popup_table.jg_popup_basic #jg_popup_br{width:10px; height:10px; background:#fff}
#jg_popup_table.jg_popup_basic #jg_popup_close{position:absolute; right:-13px; top:-13px; cursor:pointer; width:30px; height:30px; background:url(../images/3_close.svg) no-repeat}
