<a class="product" href="http://www.amazon.com/Father-T-shirt-Small-Kelly-Green/dp/B01ELXTKW0">
  <div class="product-sizes">
    <span class="sr-only">Available in the following sizes: </span>
    <i class="fa fa-male" title="Men"></i>
  </div>
  <div class="tab-content">
    <div class="tab-pane active" id="father-kelly-green">
      <img src="http://ecx.images-amazon.com/images/I/81QUekkdt7L._UX679_.jpg">
    </div>
    <div class="tab-pane" id="father-navy">
      <img src="http://ecx.images-amazon.com/images/I/817wsSl9ScL._UX679_.jpg">
    </div>
  </div>

  <ul class="list-inline text-center margin-bottom-0">
    <li class="active"><span data-target="#father-kelly-green" data-toggle="tab"><span class="swatch swatch-kellygreen" title="Kelly Green"></span> <span class="sr-only"> Kelly Green</span></span></li>
    <li><span data-target="#father-navy" data-toggle="tab"><span class="swatch swatch-navy" title="Navy"></span><span class="sr-only"> Navy</span></span></li>
  </ul>

  <hr />

  <div class="gg margin-bottom-sm">
    <h3 class="gg-col product-title margin-top-0 margin-bottom-0 padding-right-sm">Fa-ther Tee</h3>
    <h3 class="gg-col text-right text-success margin-top-0 margin-bottom-0">$28</h3>
  </div>
  <div class="text-muted">
    American Apparel Fine Jersey Short Sleeve T-Shirt
  </div>
</a>
