<footer id="footer" class="footer hidden-print">
  <div class="container text-center">
    <div id="inventory">
      <a href="http://www.wpbeginner.com/?utm_source=fontawesome_footer&utm_medium=banner&utm_campaign=fontawesome"
          title="Beginner's Guide to WordPress" target="_blank" rel="nofollow"
          onClick="_gaq.push(['_trackEvent', 'Outbound Link', 'wpbeginner.com']);">
        <img src="{{ page.relative_path }}assets/img/logo-wpbeginner.png" width="220" height="65" alt="">
      </a>
      <a href="http://themeisle.com/?utm_source=fontawesome_footer&utm_medium=banner&utm_campaign=fontawesome"
          title="Premium Wordpress Themes" target="_blank" rel="nofollow"
          onClick="_gaq.push(['_trackEvent', 'Outbound Link', 'themeisle.com']);">
        <img src="{{ page.relative_path }}assets/img/logo-themeisle.png" width="220" height="65" alt="">
      </a>
    </div>
    <div>
      <i class="fa fa-flag" aria-hidden="true"></i> Font Awesome {{ site.fontawesome.version }}
      <span class="hide-xs">&middot;</span><br class="hide-sm hide-md hide-lg">
      Created by <a href="https://twitter.com/{{ site.fontawesome.author.twitter }}">Dave Gandy</a>
    </div>
    <div>
      Font Awesome licensed under <a href="{{ site.fontawesome.license.font.url }}">{{ site.fontawesome.license.font.version }}</a>
      <span class="hide-xs">&middot;</span><br class="hide-sm hide-md hide-lg">
      Code licensed under <a href="{{ site.fontawesome.license.code.url }}">{{ site.fontawesome.license.code.version }}</a>
      <span class="hide-xs hide-sm">&middot;</span><br class="hide-md hide-lg">
      Documentation licensed under <a href="{{ site.fontawesome.license.documentation.url }}">{{ site.fontawesome.license.documentation.version }}</a>
    </div>
    <div>
      Thanks to <a href="http://tracking.maxcdn.com/c/148092/3982/378/"><i class="fa fa-maxcdn"></i> MaxCDN</a> for providing the excellent <a href="https://www.bootstrapcdn.com/fontawesome/">BootstrapCDN for Font Awesome</a>
    </div>
    <div class="project">
      <a href="{{ site.fontawesome.github.url }}">GitHub Project</a> &middot;
      <a href="{{ site.fontawesome.github.url }}/issues">Issues</a> &middot;
      <a href="{{ page.relative_path }}3.2.1">Old 3.2.1 Docs</a>
    </div>
  </div>
</footer>
