<div id="accessibility-background">
  <h4 class="margin-top-none">About Icon Fonts &amp; Accessibility</h4>
  <p>
    Modern versions of assistive technology, like screen readers, will read CSS generated content (how Font Awesome icons are rendered), as well as specific Unicode characters. When reading our default markup for rendering icons, assisistive technology may have the following problems.
  </p>

  <ul>
    <li>
      The assistive technology may not find any content to read out to a user
    </li>
    <li>
      The assistive technology may read the unicode equivalent, which could not match up to what the icon means in context, or worse is just plain confusing
    </li>
  </ul>
</div>
