<?php
/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 */

echo "<html>
<head>
<title>Registration success</title>
<style>
  body { text-align: center; padding: 150px; }
  h1 { font-size: 50px; }
  body { font: 18px Helvetica, sans-serif; background-color: #e2e0e0; text-align: center; }
  .content { display: block; text-align: center; width: 700px; margin: 0 auto; }
</style>
</head>
<body>
<div class='content'>
    <h3>You have been successfully registered to Roundpin !</h3>
    <div>
        <p>You can access the <a href='" . $_SERVER['REQUEST_SCHEME'] . "://" . $_SERVER['HTTP_HOST'] . "/roundpin-login.php'>login page</a> and use your username and
           password to log in.</p>
    </div>
</div>
</body>
</html>";

?>
