<?php
/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 */

 echo "<html>
 <head>
 <title>New Email Message</title>
 <style>
   body { text-align: center; padding: 150px; }
   h1 { font-size: 50px; }
   body { font: 18px Helvetica, sans-serif; background-color: #e2e0e0; text-align: center; }
   .content { display: block; text-align: center; width: 700px; margin: 0 auto; }
 </style>
 </head>
 <body>
 <div class='content'>
    <h3>Your email address has been verified.</h3>
    <div>
        <p>A new email message has been sent to your email address. Please follow the instructions in the new email to regain access to
           your Roundpin account.</p>
    </div>
 </div>
 </body>
 </html>";

?>
