<div id="getting-support">
  <h2 class="page-header">Getting Support</h2>
  <p>
    Having trouble getting Font Awesome up and running? Something not working the way you think it should? I hate that
    I don't have time to answer Font Awesome support emails anymore. So here are some things you might wanna do:
  </p>
  <ol>
    <li>
      Make sure you've read the latest version of how to <a href="{{ page.relative_path }}get-started/">get started</a>.
      It's been updated recently to make Font Awesome even easier to use.
    </li>
    <li>
      Check out the <a href="http://stackoverflow.com/questions/tagged/font-awesome">existing questions tagged as
      Font Awesome</a> over on Stack Overflow. Other folks might have had the same question you've had.
    </li>
    <li>
      Can't find the answer to your question on Stack Overflow?
      <a href="http://stackoverflow.com/questions/ask?tags=font-awesome">Ask a new question</a>, then
      <a href="mailto:{{ site.fontawesome.author.email }}">send me an email</a> and I might be able to take a look.
    </li>
  </ol>
</div>
