<!DOCTYPE html>
<html lang="en">
<head>
  <!-- Basic Page Needs
 ================================================== -->
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width,initial-scale=1">
  <meta name="description" content="Font Awesome, the iconic font and CSS framework">
  <meta name="author" content="Dave Gandy">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <link rel="shortcut icon" href="{{ page.relative_path }}assets/ico/favicon.ico">

  <title>{% if page.title %}{{ page.title }}{% endif %}</title>

  <!-- CSS
  ================================================== -->
  <link rel="stylesheet" href="{{ page.relative_path }}assets/css/site.css">
  <link rel="stylesheet" href="{{ page.relative_path }}assets/css/pygments.css">
  <link rel="stylesheet" href="{{ page.relative_path }}assets/font-awesome/css/font-awesome.css">

  <!--[if lt IE 9]>
    <script src="{{ page.relative_path }}assets/js/html5shiv.js"></script>
    <script src="{{ page.relative_path }}assets/js/respond.min.js"></script>
  <![endif]-->

  <script src="https://use.fonticons.com/ffe176a3.js"></script>

  <script>
    var _gaq = _gaq || [];
    _gaq.push(['_setAccount', 'UA-30136587-1']);
    _gaq.push(['_trackPageview']);

    (function() {
      var ga = document.createElement('script');
//      ga.src = 'https://www.google-analytics.com/ga.js';
      var s = document.scripts[0];
      s.parentNode.insertBefore(ga, s);
    })();
  </script>
</head>
<body class="font-awesome {{ page.view_class }}">
  <div id="wrap"> <!-- necessary for sticky footer. wrap all content except footer -->
    {% include navbar.html %}

    {{ content }}
  </div>
  {% include footer.html %}
  {% include modals/fa5.html %}
<!--
  <script src="https://platform.twitter.com/widgets.js"></script>
  <script src="https://ajax.googleapis.com/ajax/libs/jquery/{{ site.jquery.version }}/jquery.min.js"></script>
  <script src="https://ajax.aspnetcdn.com/ajax/jquery.validate/{{ site.jquery_validate.version }}/jquery.validate.min.js"></script>
  <script src="https://maxcdn.bootstrapcdn.com/bootstrap/{{ site.bootstrap.version }}/js/bootstrap.min.js"></script>
  <script src="https://cdn.jsdelivr.net/algoliasearch/3.13.1/algoliasearch.jquery.min.js" integrity="sha256-2MTQjOt4Q02v+W/QjgCO5yv+si9RAo/o/RGR5alVYzY=" crossorigin="anonymous"></script>
  <script src="https://cdn.jsdelivr.net/algoliasearch.helper/2.9.1/algoliasearch.helper.min.js" integrity="sha256-MhjLBzVVNkMEKnIE2ueYNb7QSj+oiSv4x89dlui09hg=" crossorigin="anonymous"></script>
  <script src="https://cdn.jsdelivr.net/underscorejs/1.8.3/underscore-min.js" integrity="sha256-obZACiHd7gkOk9iIL/pimWMTJ4W/pBsKu+oZnSeBIek=" crossorigin="anonymous"></script>
  <script src="https://cdn.jsdelivr.net/backbonejs/1.2.2/backbone-min.js" integrity="sha256-p6bkfFqmxtebrKOS+wyGi+Qf3d111eWUQP67keyXJ6Q=" crossorigin="anonymous"></script>
  <script src="https://cdn.jsdelivr.net/jsdelivr-rum/1.5/jsdelivr-rum.min.js" integrity="sha256-HlY2rbkgbiHhtilMXmQ86rjL/EIxGDtdg9GU9/T2ZxE=" crossorigin="anonymous"></script>
-->
  <script src="{{ page.relative_path }}assets/js/site.js"></script>
  <script src="{{ page.relative_path }}assets/js/search.js"></script>
  <script src="{{ page.relative_path }}assets/js/monetization.js" type="text/javascript"></script>

  <script>
    (function(){
      // format, zoneKey, segment:value, options
      _bsa.init('imageonly', 'CVADP2Y', 'placement:demo', {
        target: '#inventory',
        disable_css: true,
        path: 'http://inventory.fontawesome.io/api/inventory?zone=CVADP2Y'
      });
    })();
  </script>

  <!-- Facebook Pixel Code -->
  <script>
  !function(f,b,e,v,n,t,s){if(f.fbq)return;n=f.fbq=function(){n.callMethod?
  n.callMethod.apply(n,arguments):n.queue.push(arguments)};if(!f._fbq)f._fbq=n;
  n.push=n;n.loaded=!0;n.version='2.0';n.queue=[];t=b.createElement(e);t.async=!0;
  t.src=v;s=b.getElementsByTagName(e)[0];s.parentNode.insertBefore(t,s)}(window,
  document,'script','https://connect.facebook.net/en_US/fbevents.js');

  fbq('init', '590758314440297');
  fbq('track', "PageView");</script>
  <noscript><img height="1" width="1" style="display:none"
  src="https://www.facebook.com/tr?id=590758314440297&ev=PageView&noscript=1"
  /></noscript>
  <!-- End Facebook Pixel Code -->
  </body>
</html>
