<section id="tell-me-thanks">
  <h2 class="page-header">Tell Me Thanks</h2>
  <p class="lead">
    Hopefully you think Font Awesome <em>is</em> awesome. I've put hundreds of hours into the project to give back to the
    open source community. If you'd like, here are a couple of ways you can tell me thanks for all my hard work.
  </p>
  <div class="row">
    <div class="col-md-6 col-sm-6">
      <h3><a href="https://www.gittip.com/davegandy/"><i class="fa fa-gittip padding-right-sm" aria-hidden="true"></i>Tip me on Gittip</a></h3>
      <p>
        Gittip is a great way to let developers know you appreciate their work.
      </p>
    </div>
    <div class="col-md-6 col-sm-6">
      <h3><a href="http://amzn.com/w/G64X58AY416W" target="_blank">My Amazon Wish List</a></h3>
      <p>
        Or pick something straight
        from <a href="http://amzn.com/w/G64X58AY416W" target="_blank">my wish list</a>. Gift cards are great.
      </p>
    </div>
  </div>
</section>
