#social-buttons {
  ul.list-inline { margin-bottom: 0; }

  padding: 22px 0 17px;
  text-align: center;
  background-color: #f5f5f5;
  border-top: 1px solid #fff;
  border-bottom: 1px solid #eee;
}

#subscribe {
  padding: 22px 0 17px;
  text-align: center;
}

label.error {
  color: @state-danger-text;
  margin-top: 5px;
}
