.well-transparent { background-color: transparent; }

.well-lg {
  padding: @buffer-xl;
  font-size: @font-size-large + 3;
  h1 { font-size: 3em; }
  h2 { font-size: 2em; }
  h1, h2 { margin-top: 0; }
  p { margin-bottom: 30px; }
}
