<?php
/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 */

if (!defined('RESTRICTED')) {
    die();
};

// Change to true if you want to enable access to "roundpin-setup.php" in the browser, or to false to disable it
$installcheck = false;

// Change to true to activate the registration tab on the Roundpin login page, or to false to disable it
$signupcheck = false;

?>
