<div class="modal" id="modal-fa5" tabindex="-1" role="dialog" aria-labelledby="modal-fa5-label">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header bg-fa5">
        <button type="button" class="close" data-dismiss="modal" aria-label="Close"><i class="fa fa-times" aria-hidden="true"></i><span class="close"></span></button>
        <h3 class="modal-title" id="modal-fa5-label">Font Awesome 5 Released!</h3>
      </div>
      <div class="modal-body">
        <div class="row margin-bottom-lg margin-top">
          <div class="col-md-2 col-sm-2 col-xs-2 text-right padding-right-sm">
            <i class="fas fas-trophy-alt fas-3x fas-fw text-muted hidden-xs"></i>
            <i class="fas fas-trophy-alt fas-2x fas-fw text-muted hidden-sm hidden-md hidden-lg"></i>
          </div>
          <div class="col-md-9 col-sm-9 col-xs-9">
            <h4 class="page-header margin-top-none padding-bottom-sm margin-bottom-sm">More Icons</h4>
            <p>
              Get 893 icons right now with FA Free, plus another 1,283 icons with Pro, which also gets you another 46 icon category packs as we finish them!
            </p>
          </div>
        </div>
        <div class="row margin-bottom-lg">
          <div class="col-md-2 col-sm-2 col-xs-2 text-right padding-right-sm">
            <i class="fas fas-flask fas-3x fas-fw text-muted hidden-xs"></i>
            <i class="fas fas-flask fas-2x fas-fw text-muted hidden-sm hidden-md hidden-lg"></i>
          </div>
          <div class="col-md-9 col-sm-9 col-xs-9">
            <h4 class="page-header margin-top-none padding-bottom-sm margin-bottom-sm">All-New SVG</h4>
            <p>
              Our all-new SVG with JavaScript gives you all the power of SVG without the usual hassle.
            </p>
          </div>
        </div>
        <div class="row margin-bottom-lg">
          <div class="col-md-2 col-sm-2 col-xs-2 text-right padding-right-sm">
            <i class="fas fas-rocket fas-3x fas-fw text-muted hidden-xs"></i>
            <i class="fas fas-rocket fas-2x fas-fw text-muted hidden-sm hidden-md hidden-lg"></i>
          </div>
          <div class="col-md-9 col-sm-9 col-xs-10">
            <h4 class="page-header margin-top-none padding-bottom-sm margin-bottom-sm">Tons More</h4>
            <p>
              Ligatures for easier desktop use, shim for quick upgrades from 4, and more styles, icons, and tools with FA Pro.
            </p>
          </div>
        </div>

        <a target="_blank" href="https://fontawesome.com/?utm_source=font_awesome_homepage&utm_medium=display&utm_campaign=fa5_released&utm_content=auto_modal" class="btn btn-fa5 btn-lg btn-block">
          <h3 class="margin-top margin-bottom strong">
            Font Awesome 5 &nbsp;<i class="fas fas-external-link" aria-hidden="true"></i>
          </h3>
        </a>

      </div>
    </div>
  </div>
</div>
