@media (max-width: @screen-xs-max) {
  #icon-carousel {
    @size: 180px;
    font-size: @size;
    line-height: @size + 30;
    width: 280px;
    margin: 30px auto 0;
  }
  .carousel-control {
    top: 40%;
    .square(44px);
    font-size: 44px;
    line-height: 44px;
    left: -7px;
    &.right { right: -7px; }
  }

  .jumbotron-carousel {
    h1 { font-size: 58px; }
    p { font-size: 24px; }
    .btn-large {
      font-size: 20px;
      padding: 14px 26px;
    }
    .shameless-self-promotion { font-size: 12px; }
  }

  .jumbotron-ad {
    h1 { font-size: 39px; }
    p {
      font-size: 20px;
      margin-bottom: 20px;
    }
  }

  .jumbotron-icon {
    .fa-1, .fa-2, .fa-3, .fa-4, .fa-5, .fa-6 { margin-right: 0; }
    .fa-6 { font-size: 16em; }
    h1 small {
      display: block;
      margin-top: 15px;
      margin-left: 0;
      line-height: 20px;
    }
  }

  .stripe-ad .lead {
    margin-top: @buffer-lg;
    padding: 0;
  }

  #fusionads {
    float: none;
    display: block;
    margin-left: 0;
    .clearfix();
  }

  .vertical-ad #fusionads {
    width: 300px;
    .fusion-img {
      float: left;
      padding-right: 10px;
    }
  }


  .fonticons {
    padding: 15px 0;
    .tagline, .action { display: block; }
    .tagline { margin-bottom: 10px; }
  }

  .hide-xs { display: none; }

  .block-xs { display: block; }

  .modal-footer .block-xs + .block-xs {
    margin-left: 0;
    margin-top: 10px;
  }


  .navbar-org { display: none; }
  #banner {
    text-align: center;
    .message-container, .tagline, .action { display: block; }
    .tagline { padding-right: 0; }
    .btn-primary { margin-top: 10px; }
  }

  .signup-button .btn { white-space: normal; }
  .v-get-started .get-started-cdn { padding: 5px 22px 22px 22px; }
}
