/**
 *  Copyright (C) 2021  Double Bastion LLC
 *
 *  This file is part of Roundpin, which is licensed under the
 *  GNU Affero General Public License Version 3.0. The license terms
 *  are detailed in the "LICENSE.txt" file located in the root directory.
 *
 *  This is a modified version of the original file "phone.css"
 *  released under AGPL v3.0 and first modified in 2020.
 *  The copyright notice for the original content follows:
 *
 *  Copyright (c) 2020  - Conrad de Wet - All Rights Reserved.
 */

/* CSS_dhtmlxUi */

.NoSelect {
    -webkit-user-select: none;  /* Chrome all / Safari all */
    -moz-user-select: none;     /* Firefox all */
    -ms-user-select: none;      /* IE 10+ */
    user-select: none;          /* Likely future */
}

.UiText {
    font-family: Inter, sans-serif;
    color:#333333;
    font-size: 15px; 
    margin-top: 8px;
}

.UiWindowField .UiText {
    font-weight: 500 !important;
}

.UiButtonBar {
    text-align:center; 
    border-top:1px solid #e6e6e6; 
    background-color:#F3F3F3; 
    height:49px;
    vertical-align: middle;
    line-height: 49px;
}

.UiButtonBar button {
    margin: 0px;
    line-height: 100%;
    padding: 6px 6px;
    border: 1px solid #417bba;
    background-color: #417bba;
    border-radius: 3px;
    min-width: 30px;
    min-height: 24px;
    font-family: Inter, sans-serif;
    color: #FFFFFF;
    font-size: 14px;
    margin-left: 1px;
    margin-right: 1px;
    margin-top: 8px;
    outline: none;
    cursor: pointer;
}

.UiButtonBar button:hover {
    background-color: #3a6ba1;
    border: 1px solid #3a6ba1;
    color: #FFFFFF;
}

.UiButtonBar button:active {
    border: 1px solid #285480;
    background-color: #285480;
    background-image: none;
    color: #FFFFFF;
}

.UiButtonBar button:focus {
	outline: none;
}

.UiButtonBar button:disabled {
    cursor: default;
    color: #CCCCCC;
}

.UiButtonBarHtml {
    position: absolute;
    left: 0px;
    width: 100%;
    bottom: 0px;
}

.UiWindowButtonBar {
    text-align:center; 
    height: 49px;
    vertical-align: middle;
    line-height: 49px;
    padding: 11px 0px;
}

.UiWindowButtonBar button {
    margin: 0px;
    line-height: 100%;
    padding: 6px 6px;
    border: 1px solid #417bba;
    background-color: #417bba;
    border-radius: 3px;
    min-width: 80px;
    font-family: Inter, sans-serif;
    color: #FFFFFF;
    font-size: 14px;
    margin-left: 1px;
    margin-right: 1px;
    outline: none;
    cursor: pointer;
}

.UiWindowButtonBar button:hover {
    background-color: #3a6ba1;
    border: 1px solid #3a6ba1;
    color: #FFFFFF;
}

.UiWindowButtonBar button:active {
    border: 1px solid #285480;
    background-color: #285480;
    background-image: none;
    color: #FFFFFF;
}

.UiWindowButtonBar button:focus {
    outline: none;
}

.UiWindowButtonBar button:disabled {
    cursor: default;
    color: #CCCCCC;
}

#rightContent {

}

#WindowButton1, #WindowButton2 {
    margin: 0px 6px;
}

#ConfirmOkButton, #ConfirmCancelButton {
    margin: 7px 6px;
}

#confTableSection {
    display: block;
    margin: 38px 0px 20px 0px;
    font-family: Inter, sans-serif;
    color: #333333;
    font-size: 16px;
    text-align: left;
    font-weight: 700;
}

.confExtLabels {
    font-family: Inter, sans-serif;
    font-size: 14px;
    color: #333333 !important;
}

#extensionThLabel {
    margin-left: 0px;
}

#extPassThLabel {
    margin-left: 10px;
}

#extLinkThLabel {
    margin-left: 11px;
}

.extConfExtension {
    width: 60px !important;
}

.extConfExtensionPass {
    width: 103px !important;
    margin: 0px 6px;
}

.extConfExtensionLink {
    width: 90% !important;
}

.saveExtConfExtension {
  display: inline-block;
  padding: 3px 8px 4px 8px;
  border: 1px solid #65c98d;
  background-color: #65c98d;
  font-family: Inter, sans-serif;
  font-weight: 700;
  color: #FFFFFF;
  font-size: 14px;
  border-radius: 4px;
  cursor: pointer;
}

.saveExtConfExtension:hover {
  background-color: #60b582;
  border-color: #60b582;
  box-shadow: none  !important;
}

.saveExtConfExtension:active {
  background-color: #569c72;
  border-color: #569c72;
  box-shadow: none  !important;
} 

.deleteExtRow {
  margin: 0px 6px;
  font-weight: 900;
  cursor: pointer;
}

.deleteExtRowDisabled {
  pointer-events: none !important;
}

.deleteExtRow:hover {
  color: #961818;
}

#add_New_External_User {
    display: block;
    margin: 18px 0px 30px 0px;
    padding: 6px 12px 7px 12px;
    border: 1px solid #65c98d;
    background-color: #65c98d;
    font-size: 14px;
    font-family: Inter, sans-serif;
    font-weight: 700;
    color: #FFFFFF;
    border-radius: 4px;
    cursor: pointer;
    outline: none;
    float: right !important;
}

#add_New_External_User:hover {
    border: 1px solid #60b582;
    background-color: #60b582;
    color: #FFFFFF;
}

#add_New_External_User:active {
    border: 1px solid #569c72;
    background-color: #569c72;
    color: #FFFFFF;
}

#Save_New_User_Password, #Save_New_User_Email, #Close_User_Account {
    display: block;
    margin: 0px;
    padding: 7px 12px;
    border: 1px solid #4c84c2;
    background-color: #4c84c2;
    font-size: 14px;
    font-family: Inter, sans-serif;
    color: #FFFFFF;
    border-radius: 4px;
    cursor: pointer;
    outline: none;
}

#Save_New_User_Password:hover, #Save_New_User_Email:hover, #Close_User_Account:hover {
    border: 1px solid #396da8;
    background-color: #396da8;
    background-image: linear-gradient(#5686ba, #3b6fa8);
    color: #FFFFFF;
}

#Save_New_User_Password:active, #Save_New_User_Email:active, #Close_User_Account:active {
    border: 1px solid #205b96;
    background-color: #205b96;
    background-image: none;
    color: #FFFFFF;
}

.UiInputText{
    margin-bottom: 15px !important;
    font-size: 16px !important;
    color: #333333 !important;
    width: 100% !important;
    padding-top: 10px !important;
    padding-bottom: 10px !important;
    padding-left: 3px !important;
}

.UiWindowField {
    position: relative;
    padding-top: 8px;
    padding-bottom: 0px;
    padding-left: 5.7%;
    padding-right: 5.7%;
    font-family: Inter, sans-serif;
    color: #333333;
    font-size: 14px;
    line-height: 1.5;
    height: 100%;
    overflow-y: auto;
    overflow-x: hidden;
}

.PastePreviewContainer {
    display: block;
    width: 150px;
    height: 150px;
    border: 10px solid #FFFFFF;
    border-radius: 200px;
    background-color: #F3F3F3;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, 0.2);
}

.PastePreview {
    max-width: 340px;
    max-height : 340px;
    border: 1px solid #CCCCCC;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, 0.25);
    margin: 5px;
    background-color: #F3F3F3;
    border: 10px solid #FFFFFF;
    border-radius: 200px;
}

.FullScreenVideo{
    position: fixed !important;
    top: 0px !important;
    left: 0px !important;
    display: block;
    width: 100% !important;
    height: 100% !important;
    background-color: #000000 !important;
    margin: 0px !important;
    padding: 0px !important;
    z-index: 2147483647 !important;
}

.dtmfButtons{
    font-size: 20px;
    color: #222222;
    width: 40px;
    height: 40px;
    padding: 2px 4px 2px 4px;
    border: 1px solid #efefef;
}

.dtmfButtons:hover{
    color: #FFFFFF;
    background-color: #222222;
}

.dtmfButtons:active{
    color: #cccccc;
    background-color: #000000;
}

.dtmfButtons div {
    font-size: 20px;
    line-height: 9px;
    margin: 0px;
    margin: 6px 0px 0px 0px;
    padding: 0px;
}

.dtmfButtons span {
    display: block;
    font-size: 9px;
    margin: 3px 0px 0px 0px;
    padding: 0px;
}

/* CSS_TabPageTemplate */

audio{
    outline: none;
}

html {
    margin: 0px;
    padding: 0px;
    height: 100%;
}

body {
    height: 100%;
    margin-top: 0px;
    margin-bottom: 0px;
    padding: 0px;
    font-family: Inter, sans-serif;
    font-size: 14px;
    line-height: 1.5;
    color: #CCCCCC;
    cursor: default;
    background-color: #F0F5FC;
    overflow: hidden;
    user-select: none !important;
}

.pageContainer{
    min-width: 300px;
    margin-left: auto;
    margin-right: auto;
    height: 100%;
    margin-top: 0px;
    margin-bottom: 0px;
    padding: 0px;
}

.smallFlag {
    height: 12px !important;
    vertical-align: middle !important;
    display: inline-block !important;
    margin-right: 5px !important;
    border: 1px solid #868686 !important;
    border-radius: 2px !important;
    background-color: #868686 !important;
}

/* ScrollBar Styling */
.scroller {
    overflow-y: auto;
    /* Firefox */
    scrollbar-color: #516896 transparent;
}

.scroller::-webkit-scrollbar {
    width: 10px;
    /* Width */
}

.scroller::-webkit-scrollbar-track {
    background: transparent;
    /* Track */
}

.scroller::-webkit-scrollbar-thumb {
    background: #516896;
    /* Handle */
    border-radius: 50px;
}

.scroller::-webkit-scrollbar-thumb:hover {
    background: #697ca2;
    /* Handle on hover */
}

.NoItems {
    margin-top: 50px;
    margin-bottom: 50px;
    margin-left: auto;
    margin-right: auto;
    text-align: center;
    width: 200px;
    border: 2px dashed #9cb5d7;
    border-radius: 15px;
    padding: 20px;
    color: #9cb5d7 !important;
}

.SelectItemArrow {
    float: left;
    margin-top: -10px;
    margin-right: -16px;
    margin-left: -10px;
}

.helpFieldset {
    background-color: #f9f9f9;
    border-right: none;
    border-left: none;
    border-color: #293442;
    font-size: 13px;
    color: #515e6f;
}

.FormTextRight {
    display: inline-block;
    text-align: right;
    padding-right: 5px;
}

.textField {
    border: 1px solid #80add4 !important;
    border-radius: 5px;
    padding-left: 3px !important;
    line-height: 22px !important;
    background-color: #fafafa !important;
    box-shadow: inset 0px 0px 3px rgba(0, 0, 0, 0.25);
    box-sizing: border-box;
}

.contentLoading {
    display: none;
    /* Start Hidden - must activate me :) */
    margin-top: 15px;
    margin-bottom: 15px;
    border: 1px solid #CCCCCC;
    border-radius: 50px;
    background-color: #FFFFFF;
    text-align: center;
    color: #333333;
    width: 90%;
    margin-left: auto;
    margin-right: auto;
    /* Optional */
    box-shadow: inset 1px 1px 5px rgba(0, 0, 0, 0.25);
    line-height: 16px;
    font-size: 11px;
    background-color: #e6e6e6;
    background-image: repeating-linear-gradient(-45deg, #e6e6e6, #e6e6e6 10px, #cfd9e8 10px, #cfd9e8 20px);
}

.required:before {
    content: "\f069";
    font-family: FontAwesome;
    color: red;
    font-size: 7px;
    vertical-align: text-top;
    margin-right: 3px;
}

.on_white{
    color: #333333;
}
.on_white:hover{
    color: #F3F3F3;
}

/* CSS_dhtmlxUiImportant */
/* ====================================================================================== */

/* Windows */
.dhxwin_fr_cover_dnd {
    display:block !important;
}
.dhxwins_vp_material div.dhxwins_mcover {
    background-color: #000000 !important;
    opacity: .6 !important;
}
.dhxwins_vp_material div.dhxwin_active {
    background-color: #FFFFFF !important;
    border-radius: 5px !important;
}
.dhxwins_vp_material div.dhxwin_hdr {
    background-color: #FFFFFF !important;
    color: #222222 !important;
}
.dhxwins_vp_material div.dhxwin_brd {
    border-color: #FFFFFF !important;
}
.dhxwins_vp_material div.dhxwin_hdr div.dhxwin_btns div.dhxwin_button, .dhxwins_vp_material div.dhxwin_hdr div.dhxwin_btns div.dhxwin_button_dis {
    margin-top: 0px !important;
    background-image: none !important;
}
.dhxwins_vp_material div.dhxwin_hdr div.dhxwin_btns div.dhxwin_button.dhxwin_button_help:before {
    content: "\f128"; /* Help */
    font-family: FontAwesome;
    position: absolute;
    line-height: 24px;
    height: 24px;
    width: 24px;
    text-align: center;
    font-size: 13px;
}
.dhxwins_vp_material div.dhxwin_hdr div.dhxwin_btns div.dhxwin_button.dhxwin_button_park:before {
    content: "\f2d1"; /* Minimise */
    font-family: FontAwesome;
    position: absolute;
    line-height: 24px;
    height: 24px;
    width: 24px;
    text-align: center;
    font-size: 13px;
}
.dhxwins_vp_material div.dhxwin_hdr div.dhxwin_btns div.dhxwin_button.dhxwin_button_minmax:before {
    content: "\f2d0"; /* Maximise */
    font-family: FontAwesome;
    position: absolute;
    line-height: 24px;
    height: 24px;
    width: 24px;
    text-align: center;
    font-size: 13px;
}
.dhxwins_vp_material div.dhxwin_hdr div.dhxwin_btns div.dhxwin_button.dhxwin_button_minmaxed:before {
    content: "\f2d2"; /* Restore */
    font-family: FontAwesome;
    position: absolute;
    line-height: 24px;
    height: 24px;
    width: 24px;
    text-align: center;
    font-size: 13px;
}
.dhxwins_vp_material div.dhxwin_hdr div.dhxwin_btns div.dhxwin_button.dhxwin_button_close:before {
    content: "\f00d"; /* Close */
    font-family: FontAwesome;
    position: absolute;
    line-height: 24px;
    height: 24px;
    width: 24px;
    text-align: center;
    font-size: 13px;
}
.dhxwins_vp_material div.dhxwin_active div.dhxwin_hdr div.dhxwin_btns div.dhxwin_button:hover {
    background-color: #b01607 !important;
    box-shadow: inset 0px 0px 0 1px #b01607 !important;
    border-radius: 5px !important;
    color: #FFFFFF;
}
.dhxwins_vp_material div.dhxwin_active div.dhx_cell_wins div.dhx_cell_statusbar_def div.dhx_cell_statusbar_text, .dhxwins_vp_material div.dhxwin_inactive div.dhx_cell_wins div.dhx_cell_statusbar_def div.dhx_cell_statusbar_text{
    height: 49px !important;
}
/* Sidebar */
.dhxsidebar_base_material div.dhxsidebar_cont div.dhx_cell_sidebar div.dhx_cell_sidebar_hdr div.dhx_cell_sidebar_hdr_icon{
    background-image: none !important;
    cursor: pointer !important;
}
.dhxsidebar_base_material div.dhxsidebar_cont div.dhx_cell_sidebar div.dhx_cell_sidebar_hdr div.dhx_cell_sidebar_hdr_icon:before{
    content: "\f0c9"; /* Bars */
    font-family: FontAwesome;
    position: absolute;
    font-size: 18px;
}
.dhxsidebar_base_material div.dhxsidebar_cont div.dhxsidebar_side.dhxsidebar_tpl_details div.dhxsidebar_side_items div.dhxsidebar_item img.dhxsidebar_item_icon{
    display: none !important;
}
.dhxsidebar_base_material div.dhxsidebar_cont div.dhxsidebar_side.dhxsidebar_tpl_details div.dhxsidebar_side_items div.dhxsidebar_item div.dhxsidebar_item_text{
    padding-left: 16px!important;
}

/* CSS_HtmlElements */
/* ====================================================================================== */
fieldset {
    border: 1px solid #333333;
    border-radius: 5px;
    text-align: left;
}

legend {
    line-height: initial !important;
    text-align: left;
}

hr {
    height: 1px;
    border: none;
    background-color: #CCCCCC;
    clear: both;
}

button {
    margin: 0px;
    line-height: 100%;
    padding-left: 6px;
    padding-right: 6px;
    border: 1px solid transparent;
    background-color: transparent;
    border-radius: 5px;
    min-width: 22px;
    min-height: 24px;
    font-family: Inter, sans-serif;
    color: #bcbcbc;
    font-size: 14px;
    margin-left: 1px;
    margin-right: 1px;
    outline: none;
    cursor: pointer;
}

button:hover {
    background-color: #333333;
    border: 1px solid #404040;
    color: #FFFFFF;
}

button:active {
    border: 1px solid #333333;
    background-color: #222222;
    background-image: none;
    color: #FFFFFF;
    box-shadow: 0px 0px 0px 2px rgba(65, 100, 147, 0.25);
    transition: box-shadow 240ms;
}

button:focus {
    outline: none;
}

button:disabled {
    cursor: default;
    color: #CCCCCC;
}

button:disabled:hover {
    cursor: default;
    color: #CCCCCC;
}

button:disabled:active {
    box-shadow: none;
    transition: none;
}

/* Text Field */
input[type=text] {
    color: #383838;
    font-size: 14px;
    padding: 1px 0px;
    line-height: 22px;
    border: none;
    border-bottom: 2px solid #a3bad9;
    background-color: transparent;
}

input[type=text]:focus {
    outline: none;
    border-bottom: 2px solid #3a6ba1;
}

/* Password Field */
input[type=password] {
    color: #3a6ba1;
    font-size: 14px;
    padding: 0px;
    line-height: 22px;
    border: none;
    border-bottom: 2px solid #a3bad9;
    font-size: 14px;
}

input[type=password]:focus {
    outline: none;
    border-bottom: 2px solid #3a6ba1;
    background-color: transparent;
}

/* Select Dropdown */
select {
    min-width: 45px;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    background-image: url('data:image/svg+xml;base64,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');
    background-size: 10px;
    background-position: center right;
    background-repeat: no-repeat;
    font-size: 14px;
    color: #3a6ba1;
    padding: 0px;
    line-height: 22px;
    vertical-align: middle;
    padding-right: 16px;
    border: none;
    border-bottom: 2px solid #a3bad9;
    background-color: transparent;
    cursor: pointer;
    white-space: nowrap !important;
    border-radius: 0px !important;
}

select:focus {
    outline: none;
    border-bottom: 2px solid #3a6ba1;
}

/* Check Boxes */
input[type=checkbox] {
    display: none;
}

input[type=checkbox] + label {
    color: #3a6ba1;
    padding: 0px;
    line-height: 22px;
    vertical-align: middle;
    display: inline-block;
    margin-right: 5px;
    cursor: pointer;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}
#notificationsCheck, #enableRCcheck {
    margin: 10px 5px 14px 0px !important;
}
input[type=checkbox] + label:before {
    font-family: FontAwesome;
    content: "\f096";
    width: 20px;
    display: inline-block;
    font-size: 18px;
    vertical-align: middle;
    line-height: 22px;
}

input[type=checkbox]:checked + label:before {
    font-family: FontAwesome;
    content: "\f046";
    width: 20px;
    display: inline-block;
    font-size: 18px;
    vertical-align: middle;
    line-height: 22px;
}

/* Radio Boxes */
input[type=radio] {
    display: none;
}

input[type=radio] + label {
    color: #3a6ba1;
    padding-top: 5px;
    padding-bottom: 5px;
    vertical-align: middle;
    display: inline-block;
    cursor: pointer;
    margin-right: 5px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

input[type=radio] + label:before {
    font-family: FontAwesome;
    content: "\f10c";
    margin-right: 3px;
    font-size: 16px;
    vertical-align: middle;
}

input[type=radio]:checked + label:before {
    font-family: FontAwesome;
    content: "\f192";
    margin-right: 3px;
    font-size: 16px;
    vertical-align: middle;
}

.pill-nav {
    display: inline-block;
    color: black;
    text-align: center;
    font-size: 16px;
    border-bottom: 1px solid #3a6ba1;
    border-radius: 3px;
    font-size: 0;
    vertical-align: middle;
    white-space: nowrap;
    line-height: initial;
    margin-top: 10px;
}

.pill-nav input[type=radio]{
    display:none;
}

.pill-nav .radio_pill{
    cursor: pointer;
    font-size: 14px;
}

.pill-nav input[type=radio] + label {
    color: #3a6ba1;
    padding-left: 7px;
    padding-right: 7px;
    padding-top: 2px;
    padding-bottom: 2px;
    vertical-align: middle;
    display: inline-block;
    cursor: pointer;
    margin-right: 0px;
}

.pill-nav input[type=radio] + label:before {
    font-family: initial !important;
    content:  initial !important;
    margin-right: initial !important;
    font-size:  initial !important;
    vertical-align:  initial !important;
}

.pill-nav input[type=radio]:checked + label{
    background-color: #3a6ba1;
    color: white;
}

.pill-nav input[type=radio]:checked + label:before {
    font-family: initial !important;
    content: initial !important;
    margin-right: initial !important;
    font-size: initial !important;
    vertical-align:  initial !important;
}

.pill-nav button:disabled {
    cursor: default;
    color: #666666;
    background-color: #333333;
}
.pill-nav button {
    border: none;
    margin: 0px;
    border-radius: 2px;
}


/* CSS_dhtmlxTemplateImportant */
/* ====================================================================================== */
div.gridbox_material.gridbox {
    border-radius: 5px !important;
    border: 1px solid #9cb5d7 !important;
}

div.gridbox_material.gridbox .xhdr {
    border-bottom: 1px solid #97b2d7 !important;
}

div.gridbox_material.gridbox table.hdr tr {
    background-color: none !important;
    border: none !important;
}

div.gridbox_material.gridbox table.hdr td {
    background-color: #9cb5d7 !important;
    border: 1px solid transparent !important;
    color: #ffffff !important;
    font-size: 14px !important;
    border-right: 1px solid transparent !important;
}

div.gridbox_material.gridbox table.hdr td:hover {
    border-right: 1px solid #839fc5 !important;
}

div.gridbox_material.gridbox table.obj.row20px tr td {
    border-right: 1px solid transparent !important;
}

div.gridbox_material.gridbox table.hdr td.dhxgrid_sort_desc_col {
    background-image: none !important;
}

div.gridbox_material.gridbox table.hdr td.dhxgrid_sort_desc_col::before {
    content: "\f0dd";
    font-family: FontAwesome;
    width: 13px;
    height: 13px;
    position: absolute;
}

div.gridbox_material.gridbox table.hdr td.dhxgrid_sort_asc_col {
    background-image: none !important;
}

div.gridbox_material.gridbox table.hdr td.dhxgrid_sort_asc_col::before {
    content: "\f0de";
    font-family: FontAwesome;
    width: 13px;
    height: 13px;
    position: absolute;
}

div.gridbox_material.gridbox table.obj.row20px tr.rowselected td {
    background-color: #ffebc1 !important;
}

div.gridbox_material.gridbox table.obj tr.rowselected td:first-child {
    border-left: 2px solid #db9f20 !important;
}

.dhtmlxcalendar_material div.dhtmlxcalendar_dates_cont ul.dhtmlxcalendar_line li.dhtmlxcalendar_cell_month_date {
    background-color: #3a6ba1;
}

.dhtmlxcalendar_material div.dhtmlxcalendar_dates_cont ul.dhtmlxcalendar_line li.dhtmlxcalendar_cell_month_date_hover {
    background-color: #3a6ba1;
}

div.dhx_popup_material div.dhx_popup_area {
    border-radius: 5px;
}

/* CSS_Phone */
/* ====================================================================================== */
.noneSelected {
    text-align: center;
    padding: 25px
}

.Settings_VolumeOutput_Container{
    display: inline-block;
    width: 100%;
    height: 4px;
    border-radius: 50px;
    border: 1px solid #CCCCCC;
    margin-top: 10px;
    background-color: #FFFFFF;
    box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.2);
}

.Settings_VolumeOutput{
    width: 5%;
    height: 4px;
    border-radius: 50px;
    background-color: rgb(14, 192, 23);
    box-shadow: inset 2px 2px 3px rgba(255, 255, 255, 0.2), inset -2px -2px 3px rgba(0, 0, 0, 0.2);
}

.clearsearchTextBtn {
    border-radius: 100px;
    cursor: pointer;
    width: 16px;
    height: 16px;
    border: none;
    background-color: transparent;
    padding: 0px;
    font-size: 13px;
    box-shadow: none;
    color: #333333;
    min-width: 0px;
    line-height: 16px
}

.clearsearchTextBtn:before {
    content: "\f05c";
    font-family: FontAwesome;
}

.clearsearchTextBtn:hover {
    background-color: transparent;
}

.clearsearchTextBtn:active {
    background-color: transparent;
}

.cleanScroller{
    /* Firefox */
    scrollbar-width: thin;
    scrollbar-color: #a6a6a6 transparent;
}

.cleanScroller::-webkit-scrollbar {
    width: 10px;
}

.cleanScroller::-webkit-scrollbar-thumb {
    background: #a6a6a6;
    border-radius: 5px;
}

.cleanScroller::-webkit-scrollbar-track {
    background: transparent;
}

.contactArea {
    height: 100%;
    overflow-y: auto;
    overflow-x: hidden;
    scrollbar-color: #79a0d4 #eaeeff;
    /* For Firefox */
    position: absolute;
    top:0;
    left:0;
    width:100%;
    z-index: 1;
    padding: 5px;
    box-sizing: border-box;
}

.buddy {
    padding: 5px;
    height: 42px;
    cursor: pointer;
    color: #333333;
    border-left: 3px solid transparent;
    position: relative;
}

.buddy:hover {
    background-color: #edf4fc;
}

.buddySelected {
    padding: 5px;
    height: 42px;
    cursor: pointer;
    color: #333333;
    background-color: #e3f1ff;
    position: relative;
    border-left: 2px solid #5f97cf;
}

.buddyActiveCall {
    padding: 5px;
    height: 38px;
    cursor: pointer;
    color: #333333;
    background-color: #E6F1FF;
    position: relative;
    border-left: 3px solid #4E8ED5;
}

.buddyActiveCallHollding {
    padding: 5px;
    height: 38px;
    cursor: pointer;
    color: #333333;
    background-color: #E6F1FF;
    position: relative;
    border-left: 3px solid #4E8ED5;
}

.lineIcon {
    border-radius: 50px;
    width: 36px;
    height: 36px;
    background-color: #4e8ed5;
    box-shadow: 1px 1px 5px rgba(0,0,0,0.25);
    float: left;
    text-align: center;
    line-height: 36px;
    padding: 0px;
    font-size: 24px;
    color: #F3F3F3;
}

.buddyIcon {
    border-radius: 50px;
    width: 36px;
    height: 36px;
    background-size: 36px;
    background-color: #CCCCCC;
    box-shadow: 1px 1px 2px rgba(0,0,0,0.25);
    float: left;
}

.callAnswerBuddyIcon {
    border-radius: 100px;
    width: 100px;
    height: 100px;
    background-size: 100px;
    background-color: #CCCCCC;
    border: 1px solid #3e3e3e;
    display: inline-block;
}

.profileContainer {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    z-index: 1;
}

.contact {
    padding: 6.2px 5px 5px 5px;
    color: #4c4c4c;
    position: relative;
    cursor: pointer;
}

.contactNameText {
    margin-left: 50px;
    margin-top: 3px;
    font-size: 14px;
    color: #363636;
    margin-right: 55px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

.contactDate {
    float: right;
    font-size: 11px;
    color: #3f3f3f;
    margin-top: 6px;
}

.presenceText {
    margin-left: 50px;
    margin-top: 0px;
    font-size: 12px;
    color: #5c5c5c;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

.searchClean {
    display: inline;
    border-radius: 3px;
    padding: 0px 1px 0px 5px;
    background-color: #fafafa;
    height: 26px;
    box-sizing: border-box;
    color: #5a5a5a;
}

.searchClean:before {
    content: "\f002";
    font-family: FontAwesome;
    color: #393f47;
    text-shadow: 1px 1px 5px rgba(0, 0, 0, 0.25);
}

.searchClean INPUT {
    border: none;
    margin-left: 5px;
    outline: none;
    background-color: transparent;
}

.searchClean INPUT:focus {
    border: none;
}

.answerCall {
    text-align: center;
    padding: 25px;
    margin-top: 10px;
}

.dialCall {
    text-align: center;
    padding: 25px;
    margin-top: 10px;
}

.progressCall {
    text-align: center;
    padding: 25px;
    margin-top: 10px;
}

.videoCall {
    margin-top: 10px;
}

.stream {
    display: none;
}

.streamSelected {
    height: 100%;
    width: 100%;
}

.streamSection {
    background-color: #fafafa;
    border-radius: 5px;
    vertical-align: top;
    position: relative;
    border: 1px solid #FAFAFA;
}

.logoSection {
    position:relative;
    padding: 5px;
    background-color: #fafafa;
    border-radius: 5px;
    vertical-align: top;
}

#searchBoxAndIcons {
    display: inline-block;
    margin: 0px 0px -6px 0px;
    padding: 0px 0px 0px 5px;
    width: 100%;
}

.streamSectionBackground, .logoSectionBackground {
    background-position-x: center;
    background-position-y: bottom;
}

.chatHistory {
    display: block;
    position: relative;
    height: 74vh !important;
    overflow: auto;
    user-select: none;
    /* For Firefox */
    top:0px;
    left:0px;
    width:100%;
    z-index: 1;
    padding: 5px;
    box-sizing: border-box;
}

.roundButtons {
    border-radius: 100px;
    cursor: pointer;
    width: 32px;
    height: 32px;
    line-height: 32px;
    border: 1px solid #B3B3B3;
    background-color: transparent;
    padding: 0px;
    font-size: 16px;
    box-shadow: none;
    color: #5f5f5f;
    min-width: 0px;
}

.roundButtonsSpec {
    border-radius: 100px;
    cursor: pointer;
    width: 32px;
    height: 32px;
    line-height: 32px;
    border: 1px solid #B3B3B3;
    background-color: transparent;
    padding: 0px;
    font-size: 16px;
    box-shadow: none;
    color: #5f5f5f;
    min-width: 0px;
    margin: 2px 0px 4px 2px;
}

.roundButtons:hover, .roundButtonsSpec:hover {
    border: 1px solid #404040;
    background-color: #333333;
}

.roundButtons:active, .roundButtonsSpec:active {
    border: 1px solid #404040;
    background-color: #222222;
    color: #FFFFFF;
}

.toolBarButtons {
    border-radius: 5px;
    cursor: pointer;
    width: 26px;
    height: 26px;
    border: 1px solid #CCCCCC;
    background-color: #ececec;
    padding: 0px;
    font-size: 14px;
    box-shadow: none;
    color: #333333;
    min-width: 0px;
    vertical-align: middle;
}

.toolBarButtons:hover {
    border: 1px solid #CCCCCC;
    background-color: #CCCCCC;
}

.toolBarButtons:active {
    border: 1px solid #666666;
    background-color: #666666;
    color: #FFFFFF;
}

.meterContainer {
    display: inline-block;
    width: 5px;
    height: 28px;
    border: 1px solid #CCCCCC;
    background-color: #ececec;
    padding: 0px;
    vertical-align: middle;
    position: relative;
    border-radius: 3px;
}

.meterLevel {
    background-color: #19ad19;
    width: 100%;
    position: absolute;
    left: 0px;
    bottom: 0px;
    border-radius: 2px;
}

.EmojiMenu {
    position: absolute;
    width: 340px;
    bottom: 124px;
    right: -5px;
    background-color: #ffffff;
    border-radius: 4px;
    z-index: 1018;
}

.sendMessagePreview {
    padding-top: 2px;
    padding-bottom: 2px;
    border-bottom: 2px solid #cecece;
    font-family: Inter, sans-serif;
    font-size: 14px;
    color: #272f39;
}

.sendMessagePreviewLeft {
    margin-right: 30px;
}

.sendMessagePreviewHtml {
    background-color: rgba(215, 232, 247, 0.8);
    padding: 5px;
    box-sizing: border-box;
    border-radius: 5px;
    display: inline-block;
    text-align: left;
    max-height: 300px;
    max-width: 85%;
    overflow-y: auto;
    overflow-x: hidden;
    color: #383838;
}

.previewImage {
    cursor: pointer;
    max-width: 320px;
    border-radius: 5px;
    border: 1px solid #929292;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, 0.25);
}

.previewHyperlink {
    color: blue;
}

.sendMessagePreviewContainer{
    width: 100%;
}

.sendMessagePreviewContainer TD {
    vertical-align: middle;
    text-align: center;
}

.sendMessageContainer {
    width: 100%;
    height: 80px;
}

.sendMessageContainer TD {
    vertical-align: top;
    text-align: center;
}

.chatMessage {
    box-sizing: border-box;
    padding: 6px;
    width: 100%;
    height: 100%;
    border: none;
    outline: none;
    resize: none;
    font-family: Inter, sans-serif;
    font-size: 15px;
    color: #4e4e4e;
    background-color: transparent;
}

.buddyIconSmall {
    display: block;
    border-radius: 50px;
    width: 18px;
    height: 18px;
    background-size: 18px;
    background-color: #CCCCCC;
    border: 1px solid #FFFFFF;
    box-shadow: 1px 1px 3px rgba(0,0,0,0.25);
}

.theirChatMessage {
    padding-left:5px;
    margin-top: 15px;
    margin-right: auto;
    max-width: 85%;
}

.theirChatMessage TD {
    vertical-align: top;
    text-align: left;
}

.theirChatMessage AUDIO {
    width: 100%;
    height: 30px;
    outline: none;
    border-radius: 5px;
    background-color: #f2f3f4;
    color: #333333;
}

.theirChatMessage  VIDEO {
    max-width: 640px;
    width: 100%;
    outline: none;
    background-color: #000000;
    border-radius: 5px;
}

.theirChatMessageText {
    display: inline-block;
    background-color: #e3faef;
    padding: 5px;
    border-radius: 5px;
    font-size: 14px;
    color: #272f39;
    position: relative;
}

.ourChatMessage {
    padding-right: 5px;
    margin-top: 15px;
    margin-left: auto;
    max-width: 85%;
}

.ourChatMessage TD {
    vertical-align: top;
    text-align: left;
}

.ourChatMessage AUDIO {
    width: 100%;
    height: 30px;
    outline: none;
    border-radius: 5px;
    background-color: #f2f3f4;
    color: #333333;
}

.ourChatMessage VIDEO {
    max-width: 640px;
    width: 100%;
    outline: none;
    background-color: #000000;
    border-radius: 5px;
}

.ourChatMessageText {
    display: inline-block;
    background-color: #e9f4ff;
    padding: 5px;
    border-radius: 5px;
    font-size: 14px;
    color: #272f39;
    position: relative;
}

.messageDate {
    font-size: 11px;
    color: #666666;
}

.messageText {
    user-select: text;
    cursor: text;
    font-size: 15px;
    word-break: keep-all;
}

.chatMessageTable {
    position: relative;
    z-index: 1020;
}

.chatMessageDropdown {
    cursor: pointer;
    position: absolute;
    right: 5px;
    width: 20px;
    height: 20px;
    line-height: 20px;
    text-align: center;
    background-color: rgba(255, 255, 255, 0.8);
    border-radius: 50px;
}

.callRecordings {
    font-size:11px
}

.callRecordings button {
    width: 30px;
    text-align: center;
    height: 30px;
    line-height: 30px;
    float: left;
    margin-right: 10px;
    color: #333333;
    background-color: #CCCCCC;
    border: 1px solid #222222;
    border-radius: 50px;
}

.callRecordings button:hover {
    color: #cccccc;
    background-color: #333333;
    border: 1px solid #222222;
}

.callRecordings img {
    width: 100%;
    max-width: 400px; /* 854x480 (16:9) */
    border-radius: 5px;
    filter: blur(1px);
    transform: scale(1.1);
}

.callRecording {
    background-color: #CCCCCC;
    border-radius: 10px;
    padding: 5px;
    margin-top: 2px;
    margin-bottom: 2px;
}

.callRecording DIV {
    overflow: hidden;
    border-radius: 5px;
}

.videoPoster {
    border-radius: 50px !important;
    margin: 0px !important;
    border: none !important;
    color: #cccccc !important;
    background-color: rgba(0, 0, 0, 0.5) !important;
    width: 50px !important;
    height: 50px !important;
    padding: 0px !important;
    position: absolute;
    left: calc(50% - 25px);
    top: calc(50% - 25px);
}

.videoPoster:hover {
    color: #e0e0e0 !important;
}

.videoPoster I {
    border: 1px solid #cccccc;
    border-radius: 50px;
    width: 48px;
    text-align: center;
    height: 48px;
    line-height: 48px;
    font-size: 24px;
    background-color: rgba(0, 0, 0, 0.5);
}

.previewVideo {
    max-height: 720px;
    max-width: 100%;
    background-color: #666666;
    border: 1px solid #222222;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, .25);
    border-radius: 5px;
    transform: rotateY(180deg);  
}

.emojiButton BUTTON {
    font-size: 23px;
    padding-left: 0px;
    padding-right: 0px;
    min-width: 30px;
    min-height: 30px;
    line-height: 28px;
    text-align: center;
}

.PreviewContainer {
    text-align: left;
    margin-top: 15px;
    position: absolute;
    left: 0px;
    right: 0px;
    z-index: 10;
}

.PreviewContainer VIDEO {
    margin-left: 10px;
    border-radius: 5px;
    background-color: #000000;
    height: auto;
    width: 15%;
}

.PreviewContainer_FS {
    height: calc(10%);
    position: absolute;
}

.PreviewContainer_FS VIDEO {
    height: 100% !important;
    width: auto !important;
}

.StageContainer {
    width: 100%;
    min-height: 360px;
    background-color: #000000;
    margin-top: 10px;
    text-align: center;
    z-index: 9;
}

.StageContainer VIDEO {
    border-radius: 0px;
    background-color: #000000;
    height: auto;
    max-height: 360px;
    width: 100%;
    max-width: 898px;
    object-fit: contain;
}

.StageContainer_FS {
    height: calc(100% - 55px) !important;
    max-height: initial !important;
}

.StageContainer_FS VIDEO {
    height: 100% !important;
    width: 100% !important;
    max-height: 100% !important;
    max-width: 100% !important;
    object-fit: cover;
}

.canvas-container {
    display: inline-block;
}

.callStatus {
    background-color: #EDEDED;
    border-radius: 50px;
    padding: 4px 0px 3px 15px;
    text-align: left;
    color: #383838;
}

.answerButton {
    background-color: #059609;
    border: none;
    padding: 4px 15px 7px 15px;
    font-weight: 500;
    color: #ffffff;
    cursor: pointer;
}

.answerButton:hover {
    background-color: #0aa80f;
    border: none;
}

.answerButton:active {
    background-color: #017a05;
}

.hangupButton {
    background-color: #dc0000;
    padding: 4px 15px 6px 15px;
    font-weight: 500;
    border: none;
    color: #ffffff;
    cursor: pointer;
}

.streamSection .hangupButton {
    margin-top: 6px;
}

.hangupButton:hover {
    background-color: #ff1b1b;
    border: none;
}

.hangupButton:active {
    background-color: #d80000;
}

.dotOnline {
    background-color: #3fbd3f;
    border: 1px solid #3fbd3f;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 30px;
    top: 28px;
    font-size: 9px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotOffline {
    background-color: #b5b5b5;
    border: 1px solid #808080;
    position: absolute;
    width: 12px;
    height: 12px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 30px;
    top: 30px;
    font-size: 9px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotRinging {
    background-color: #3fbd3f;
    border: 1px solid #148014;
    position: absolute;
    width: 12px;
    height: 12px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 30px;
    top: 30px;
    font-size: 9px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotRinging:before {
    content: "\f2a0";
    font-family: FontAwesome;
    position: absolute;
    left: 2.5px;
    top: 0px;
}

.dotInUse {
    background-color: #3fbd3f;
    border: 1px solid #148014;
    position: absolute;
    width: 12px;
    height: 12px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 30px;
    top: 30px;
    font-size: 9px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotInUse:before {
    content: "\f095";
    font-family: FontAwesome;
    position: absolute;
    left: 2.5px;
    top: 0px;
}

.dotDoNotDisturb {
    background-color: #ff6600;
    border: 1px solid #ff6600;
    position: absolute;
    width: 14px;
    height: 14px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 30px;
    top: 28px;
    font-size: 9px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotReady {
    background-color: #3fbd3f;
    border: 1px solid #148014;
    position: absolute;
    width: 12px;
    height: 12px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 30px;
    top: 30px;
    font-size: 9px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotOnHold {
    background-color: #3fbd3f;
    border: 1px solid #148014;
    position: absolute;
    width: 12px;
    height: 12px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 30px;
    top: 30px;
    font-size: 9px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.dotOnHold:before {
    content: "\f095";
    font-family: FontAwesome;
    position: absolute;
    left: 2.5px;
    top: 0px;
    color: #CCCCCC;
}

.dotFailed {
    background-color: red;
    border: 1px solid darkred;
    position: absolute;
    width: 12px;
    height: 12px;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    left: 30px;
    top: 30px;
    font-size: 9px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
}

.missedNotifyer {
    background-color: #ff0000;
    border: 1px solid #ff0000;
    position: absolute;
    width: 18px;
    height: 18px;
    line-height: 18px;
    font-weight: bold;
    border-radius: 20px;
    color: #FFFFFF;
    min-width: 0px;
    padding: 0px;
    right: 2px;
    top: 5px;
    font-size: 12px;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    margin: 0px;
    text-align: center;
}

.quickDial{
    border-radius: 100px;
    cursor: pointer;
    width: 18px;
    height: 18px;
    line-height: 18px;
    text-align: center;
    border: 1px solid #404040;
    box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.25);
    background-color: #2a2a2a;
    padding: 0px;
    font-size: 10px;
    color: #dcdcdc;
    min-width: 0px;
    position: absolute;
    top: 5px;
}

.startDragDrop {
    outline: 2px dashed #184369;
}

.progressBarContainer {
    border: 1px solid #787878;
    width: 250px;
    height: 10px;
    background-color: #fafafa;
    box-shadow: inset 0px 0px 3px rgba(0, 0, 0, 0.5);
    border-radius: 5px;
    margin-top: 5px;
    overflow: hidden;
}

.progressBarTrack {
    background-color: #19cc19;
    width: 0%;
    height: 10px;
    box-shadow: inset 3px 3px 5px rgba(255, 255, 255, 0.5);
}

.audioStats {
    padding:10px;
    overflow: auto;
    position: fixed;
    top: 0px;
    left: 0px;
    width: 100%;
    box-sizing: border-box;
    height: 100%;
    background-color: #222222;
    z-index: 99999999;
}

.audioStatsSet {
    max-width: 1240px;
    margin-left: auto;
    margin-right: auto;
}

.audioGraph {
    background-color: #FFFFFF;
    border-radius: 5px;
    margin-top: 10px;
    margin-left: auto;
    margin-right: auto;
}

.buddyProfilePic {
    display: block;
    width: 150px;
    height: 150px;
    border: 10px solid #FFFFFF;
    border-radius: 200px;
    margin-left: auto;
    margin-right: auto;
    background-size: cover;
    background-position: center;
    margin-top: 10px;
    background-color: #F3F3F3;
    box-shadow: 1px 1px 5px rgba(0, 0, 0, 0.2);
}

.ProfileTextLarge {
    font-size: 22px;
    color: #4c4c4c;
    line-height: 22px;
}

.ProfileTextMedium {
    font-size: 14px;
    color: #4c4c4c;
    line-height: 16px;
    word-wrap: break-word;
}

.ProfileTextSmall {
    font-size: 11px;
    color: #4c4c4c;
    line-height: 12px;
}

.ConferenceParticipant {
    border: 1px solid #CCCCCC;
    background-color: #FFFFFF;
    border-radius: 100px;
    display: inline-block;
    margin-right: 10px;
    margin-bottom: 10px;
    width: 240px;
    padding: 10px;
    box-sizing: content-box;
    vertical-align: top;
    height: 37px;
    font-size: 14px;
    color: #4c4c4c;
    cursor: pointer;
    box-shadow: 1px 1px 5px rgba(0,0,0,0.15);
}

.ConferenceParticipant .Talking {
    border: 3px solid green;
    border-radius: 50px;
    width: 32px;
    height: 32px;
    background-size: 32px;
    background-color: #CCCCCC;
    box-shadow: 1px 1px 5px rgba(0,255,0,0.25);
    float: left;
    margin-right: 10px;
}

.ConferenceParticipant .NotTalking {
    border: 3px solid white;
    border-radius: 50px;
    width: 32px;
    height: 32px;
    background-size: 32px;
    background-color: #CCCCCC;
    box-shadow: 1px 1px 5px rgba(0,0,0,0.25);
    float: left;
    margin-right: 10px;
}

.FlagCall {
    color: orange;
    font-size: 18px;
    vertical-align: text-top;
    text-shadow: 1px 1px 2px rgba(0, 0, 0, 0.25);
}

.SendingMessage {
    font-size: 13px;
}

.SentMessage {
    color: #0099c7;
    font-size: 13px;
}

.FailedMessage {
    color: red;
    font-size: 13px;
}

.DeliveredMessage {
    color: #0099c7;
    font-size: 13px;
}

/* Tags */
.tags {
    list-style: none;
    margin: 0;
    padding: 0;
    display: inline-block;
    vertical-align: middle;
}

.tags li {
    user-select: none;
    float: left;
    margin-bottom: 1px;
    margin-top: 1px;
    margin-left: 0px;
    margin-right: 2px;
    color: #333333;
    border: 1px solid #888888;
    background-color: rgba(255, 255, 255, 0.25);
    border-radius: 6px;
    padding: 0px;
    padding-left: 2px;
    padding-right: 5px;
    line-height: 18px;
    font-size: 12px;
    cursor: pointer;
}

.tags li:hover::before {
    content: "\f1f8";
}

.tags li::before {
    content: "\f02b";
    font-family: FontAwesome;
    width: 16px;
    display: inline-block;
    line-height: 16px;
    height: 16px;
    vertical-align: middle;
    text-align: center;
}

.tags input[type=text] {
    font-size: 12px;
    padding: 0px;
    margin: 0px;
    line-height: initial;
    color: #333333;
    border: none;
    width: 60px;
}

.tags .tagText:hover::before {
    content: "\f067";
}

.tags .tagText::before {
    content: "\f067";
}

.cdrTag {
    margin-right: 10px;
}

.cdrTag::before {
    content: "\f02b";
    font-family: FontAwesome;
    width: 16px;
    display: inline-block;
    line-height: 16px;
    height: 16px;
    vertical-align: middle;
    text-align: center;
}

.messageReadMore {
    text-align: left;
    font-size: 12px;
}

.messageReadMore span {
    text-decoration: underline;
    color: #0061c7;
    cursor: pointer;
}

.cdrComment {
    font-size: 12px !important;
    color: #444444 !important;
    line-height: initial !important;
    text-align: left;
}

.cdrComment input[type=text] {
    font-size: 12px !important;
    color: #444444 !important;
    background-color: #FFFFFF;
    border: none !important;
    line-height: initial !important;
    box-sizing: border-box;
    width:100%;
    border-radius: 3px;
    padding: 3px;
}

.inCallButtons {
    width: 45px !important;
    height: 45px !important;
    font-size: 20px !important;
    margin-left: 2px !important;
    margin-right: 2px !important;
    padding-left: 0px !important;
    padding-right: 0px !important;
}

.dialTextInput {
    width:160px;
    margin: 14px 12px;
    font-size: 16px;
    text-align: center;
    border-radius: 10px;
    border: 0.01em solid;
    border-color:#989898;
    background-color: transparent;
    outline-color: #cbe4ff;
}

#dialText:focus {
    outline: none;
}

.dialButtons {
    font-size: 24px; 
    border: none;
    color: #333333;
}

.dialButtons:hover {
    color: #f3f3f3;
    background-color: #333333;
}

.dialButtons:disabled {
    color: #666666;
}

.dialButtons:disabled:hover {
    color: #666666;
    background-color: transparent;
    border: none;
}

.timelineMessage {
    margin-left: 20%;
    color: #F3F3F3;
    border-left: 3px solid #3c5e82;
}

.timelineMessageDot {
    position: relative;
    left: -6.5px;
    color: #3c5e82;
}

.timelineMessageArea {
    color: #F3F3F3;
    padding-top: 10px;
    padding-bottom: 10px;
    padding-left: 0px;
}

.timelineMessageDate {
    color: #565656;
    font-size: 12px;
}

.timelineMessageText {
    color: #565656;
    padding: 5px;
    background-color: #ebf4ff;
    border-radius: 10px;
    margin-left: 10px;
}

#smallLogo {
    display: inline-block;
    padding: 0px 0px 0px 5px;
}

#aboutImg {
    display: inline-block;
    float: right;
    background-image: url('data:image/svg+xml;base64,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');
    background-repeat: no-repeat;
    cursor: pointer;
    margin: 0px -3px 0px 0px;
}

#aboutImg:hover {
    background-image: url('data:image/svg+xml;base64,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');
    background-repeat: no-repeat;
    background-color: #ffffff;
    border: 1px solid transparent;
}

#BtnFreeDial {
    display: inline-block;
    width: 20px;
    height: 20px;
    background-image: url('data:image/svg+xml;base64, ');
    background-repeat: no-repeat;
    vertical-align: top;
    margin-right: 2px;
}

#BtnFreeDial:hover {
    background-image: url('data:image/svg+xml;base64, ');
    background-repeat: no-repeat;
}
#collapseLeftPanel {
    background-image: url('data:image/svg+xml;base64,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');
    background-repeat: no-repeat;
}
#collapseLeftPanel:hover {
    background-image: url('data:image/svg+xml;base64,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');
    background-repeat: no-repeat;
    background-color: #ffffff;
    border: 1px solid transparent;
}
#ButtonsOnSearchLine {
    display: block;
    position: relative;
    float: right;
    margin: 0px 13px 0px 0px;
}

.fa-columns {
    cursor: pointer;
    font-size: 15.5px !important;
}

.fa-columns:hover {
    color: #626262;
}

.fa-phone {
    font-size: 16px !important;
    padding-top: 1.7px;
}

.streamSection .fa-phone {
    padding-top: 1px !important;
}

#jg_popup_inner .fa-phone {
    padding-top: 0px !important;
}

.fa-video-camera {
    font-size: 14px !important;
    padding: 2px 1px 0px 1px;
}

.fa-wifi {
    padding-top: 3px;
    font-size: 12px !important;
}

#LaunchVideoConf {
    display: inline-block;
    vertical-align: top;
    margin: 0px 2px 5px 5px;
    padding: 0px 1.5px 0px 1.5px;
}

#LaunchVideoConf .fa-users {
    font-size: 18px !important;
    color: #626262;
}

#LaunchVideoConf .fa-users:hover {
    color: #ffffff;
}

#BtnSettings {
    display: inline-block;
    vertical-align: top;
    margin: 0px 1px 5px 4px;
    padding: 0px 2.5px 0px 2.5px;
}

.fa-cog {
    font-size: 20px !important;
    color: #626262;
}

.fa-cog:hover {
    color: #ffffff;
}

.fa-chevron-left {
    padding-right: 3px;
}

.fa-chevron-down {
    padding-top: 2px;
}

.fa-ellipsis-h {
    padding-top: 1.5px;
}
#inLogoSection {
    display: inline-block;
    position: relative;
    float: right;
}
#emailInLogoSection {
    display: inline-block;
    color: #939393;
    cursor: pointer;
    margin: 10px 11px 0px 0px;
    vertical-align: top;
}
#aboutInLogoSection {
    display: inline-block;
    margin: 12px 11px 0px 0px;
}
#shrinkLeftPanel {
    display: inline-block;
    vertical-align: bottom;
    margin: 4px 10px 8px 0px;
    width: 8px;
    height: 18px;
    cursor: pointer;
}
.fa-envelope-o {
    font-size: 19px;
}
.fa-envelope-o:hover {
    color: #212121;
}
.fa-pencil-square-o {
    display: none;
}

.buddyIcon:hover .fa-pencil-square-o {
    display: block;
    position: relative;
    margin-left: -5px;
}

#AboutLogoImg {
    display: block;
    margin: 16px auto 22px auto;
    width: 270px;
    height: auto;
}

.confTable {
    display: block;
    overflow: auto;
}

#vidConfExternalTable td {
    display: inline-block;
}

.btnTableRow {
    display: block;
    margin-bottom: 8px;
}

.copyToClipboard {
    padding: 2px 0px 0px 0px;
    color: #cccccc;
}

#ConfirmMessageText {
    padding: 0px 10px 10px 10px !important;
    font-size: 15px;
}


/* Modals */

#jg_popup_table.jg_popup_basic {
    background-color: #fff;
}
#jg_popup_overlay {
    z-index:2100;
}
#jg_popup_inner {
    z-index:2102;
}
.addContactPopup, .editContactPopup {
    padding-top: 20px;
    padding-bottom: 20px;
}
#aboutPopup {
    display: block;
    position: relative;
    font-size: 16px !important;
    color: #333333 !important;
    width: 100% !important;
    height: auto;
}
#ok_button {
    display: block;
    padding: 7px 12px;
    margin: 14px auto 10px auto;
    font-size: 16px;
    color: #ffffff;
    background: #457CC4;
}
.confirmDelContact, .ConfCloseAccount {
    padding: 20px 14px 16px 14px !important;
    line-height: 1.5;
}
#bottomButtons, #ConfDelContact, #ConfCloseAccount {
    display: block;
    background: #ffffff;
    width: 100%;
    height: auto;
    text-align: center;
}
#bottomButtonsConf {
    display: block;
    margin: 20px auto 0px auto;
    text-align: center;
}
#save_button_conf {
    display: inline-block;
    padding: 7px 12px;
    font-size: 16px;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 8px 10px 8px;
    border-radius: 4.5px;
}
@media (max-width: 555px) {
  #cancel_button_conf {
    display: inline-block;
    padding: 7px 12px;
    font-size: 16px;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 80px 10px 8px;
    border-radius: 4.5px;
  }
}
@media (min-width: 556px) {
  #cancel_button_conf {
    display: inline-block;
    padding: 7px 12px;
    font-size: 16px;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 208px 10px 8px;
    border-radius: 4.5px;
  }
}
#save_button, #cancel_button {
    display: inline-block;
    padding: 7px 12px;
    font-size: 16px;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 8px 10px 8px;
    border-radius: 4.5px;
}
#ConfirmOkButton, #ConfirmCancelButton, #PromptOkButton, #PromptCancelButton, #AlertOkButton {
    display: inline-block;
    padding: 6px 11px;
    font-size: 16px;
    border: none;
    color: #ffffff;
    background: #457CC4;
    margin: -4px 8px 10px 8px;
    border-radius: 4.5px;
}
#ok_button:hover, #save_button:hover, #cancel_button:hover, #save_button_conf:hover, #cancel_button_conf:hover, #ConfirmOkButton:hover, #ConfirmCancelButton:hover, #PromptOkButton:hover, #PromptCancelButton:hover, #AlertOkButton:hover {
    background: #3367AB;
}
#ok_button:active, #save_button:active, #cancel_button:active, #save_button_conf:active, #cancel_button_conf:active, #ConfirmOkButton:active, #ConfirmCancelButton:active, #PromptOkButton:active, #PromptCancelButton:active, #AlertOkButton:active {
    background: #265694;
}
#jg_popup_content a {
    text-decoration: none;
    color: #1157a0 !important;
}

#jg_popup_table.jg_popup_basic #jg_popup_close {
    display: none !important;
}
#jg_popup_table.jg_popup_basic #jg_popup_title {
    height:auto; font-size: 16px; text-align: center; color: #9d9d9d;
}
#jg_popup_table.jg_popup_basic #jg_popup_tr {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_tl {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_b {
    height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_bl {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_br {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_l {
    width:3px; height:3px; background:#fff
}
#jg_popup_table.jg_popup_basic #jg_popup_r {
    width:3px; height:3px; background:#fff
}
#userMenu {
    cursor: pointer;
}
#userMenu #userMenuTable tr td {
    display: block;
    margin: 4px auto;
    color: #363636;
}
#userMenu #userMenuTable tr td:hover {
    color: #000000 !important;
}
.userMenuContent { 
    padding: 4px 10px;
}
#mainDialPad {
   padding-bottom: 8px !important;
}
#mainDtmfDialPad {
   margin: 5px auto;
}
#jg_popup_inner {
   border-radius: 6px;
   box-shadow: 0 0 23px rgba(0, 0, 0, 0.1)  ; 
   -webkit-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1)  ; 
   -moz-box-shadow: 0 0 23px rgba(0, 0, 0, 0.1)  ; 
}
#jg_popup_table.jg_popup_basic {
   border: 3px solid #ffffff;
   border-radius: 6px;   
}
#jg_popup_table tbody {
   border: 3px solid #ffffff;
   border-radius: 6px;
}
#videoConfMenu, #settingsCMenu {
   cursor: pointer;
}
#videoConfMenu #lauchVConfTable tr td {
   display: block;
   margin: 0px 0px 0px 3.4px !important;
   color: #363636;
}
#settingsCMenu #lauchSetConfTable tr td {
   display: block;
   margin: 0px 0px 0px 4px !important;
   color: #363636;
}
#videoConfMenu #lauchVConfTable tr td:hover, #settingsCMenu #lauchSetConfTable tr td:hover {
   color: #000000 !important;
}
#windowCtrls {
   display: block;
   position: absolute;
   float: right;
   width: auto;
   height: auto;
   top: 5px;
   right: 3px;
}
#minimizeImg, #maximizeImg, #closeImg {
   display: inline-block;
   width: 18.4px;
   height: 18.4px;
   margin: 0px 3px 0px 3px;
   cursor: pointer;
}
#minimizeImg:hover, #maximizeImg:hover, #closeImg:hover {
   box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
   -webkit-box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
   -moz-box-shadow: 0 0 9px rgba(0, 0, 0, 0.1); 
}
.quickNumDialRow, .quickFindBdRow, #showEmojiRow {
   color: #363636 !important;
   cursor: pointer;
}
.quickFindBdTagRow {
   color: #363636 !important;
}
.quickNumDialRow:hover, #showEmojiRow:hover {
   color: #000000 !important;
}
.ourChatMessage td, .theirChatMessage td {
   padding: 10px 12px 10px 12px;
}
.callSettingsContent {
   padding: 10px 10px 16px 10px;
}
.callSettingsDvs {
   padding: 6px 0px 6px 3px;
   font-size: 14px;
   color: #b0b0b0;
}
#settingsCMenu_1 {
   z-index: 20100;
}

#leftPanelSettings tr td {
   color: #363636;
   cursor: pointer;
}
#leftPanelSettings tr td:hover {
   color: #0F4685;
}
#messageMenuTable tr td {
   color: #363636;
   cursor: pointer;
}
#messageMenuTable tr td:hover {
   color: #000000 !important;
}
#mainRightConf {
   position: relative;
   display: inline-block;
   height: 100%;
   width: 100%;
}
#rightMainConfWindow {
    position: relative;
    padding: 22px 10px 20px 10px;
    height: 100%;
    width: auto;
    overflow-y: auto !important;
    overflow-x: hidden;
    scrollbar-color: #516896 transparent;
}
.settingsSubSection {
    display: block;
    margin: 0px 8px 50px 2px; 
}
#rightMainConfWindow .UiText {
    font-weight: 500 !important;
}
#settingsTitle {
    display: block;
    padding-right: 200px;
    margin-bottom: 8px;
}
.selectedSettingsSection {
    color: #1667C9 !important;
    font-weight: 500;
}
#AllertMessageText {
    font-size: 15px !important; 
}


/* Other elements */

#roundcubeFrame {
    display: block;
    position: relative;
    height: 100%;
    width: 100%;
    z-index; 1010;
}
.fa-paper-plane-o {
    margin: 0px 2px 1px 0px;
    padding: 0px;
}
#rcLogoutFrame {
    width: 100%;
    height: 100%;
    visibility: hidden;
}
#rcForm, #rcloForm {
    visibility: hidden;
}
#enableRCcheck label {
   word-break: normal !important;
   white-space: normal !important;
}
.quickDial .fa-envelope-o {
   margin: 1.5px 0px 0px 0px !important;
   font-size: 14px !important;
   font-weight: 900 !important;
   color: #dcdcdc !important;
}
.quickDial .fa-envelope-o:hover {
   color: #dcdcdc !important;
}
#loaderImage {
   display: block;
   position: absolute;
   margin: auto;
   vertical-align: center;
}
#rcLogoutMessage {
   display: block;
   position: absolute;
   margin: auto;
}
.shrinkLeftContent {
   display: inline-block;
   position: absolute;
   float: left;
   height: 100%;
   width: 320px;
   left: -280px;
}
.widenRightContent {
   display: inline-block;
   position: absolute;
   margin-left: 40px !important;
   height: 100%;
   width: 97.5%;
   overflow: auto;
}
#sendFileFormChat {
   display: none;
   position: absolute;
   width: 100%;
   height: 50px;
   text-align: center;
   bottom: 100px;
   background-color: #EAEEF5;
   z-index: 1016;
}
input[type="file"] {
   display: none;
}
.customBrowseButton {
   display: inline-block;
   position: relative;
   width: 80px;
   height: auto;
   padding: 4px 11px;
   font-size: 16px;
   color: #ffffff;
   cursor: pointer;
   background-color: #65c98d;
   border-radius: 4px;
   overflow: hidden;
   margin: 11.5px auto;
}
.customBrowseButton:hover {
   background-color: #60b582;
}
.customBrowseButton:active {
   background-color: #569c72;
}
#upFile {
   display: inline;
   position: relative; 
   color: #393939;
   font-size: 16px;
   bottom: 20px;
   left: 10px;
}
.sentFileChatRect {
   display: block;
   position: relative;
   float: right;
   padding: 10px;
   height: auto;
   width: 300px;
   font-size: 16px;
   color: #393939;
   background-color: #E9F4FF;
   border-radius: 4px;
   text-align: center;
   word-wrap: break-word;
}
.sentFileChatRect a {
   text-decoration: none;
   color: #1157a0 !important;
}
.recFileChatRect {
   display: block;
   position: relative;
   float: left;
   padding: 10px;
   height: auto;
   width: 300px;
   font-size: 16px;
   color: #393939;
   background-color: #E3FAEF;
   border-radius: 4px;
   text-align: center;
   word-wrap: break-word;
}
.recFileChatRect a {
   text-decoration: none;
   color: #1157a0 !important;
}
#sendFileLoader {
   display: block;
   position: relative;
   width: 66px;
   height: 66px;
   left: 50%;
   margin-top: -180px;
   background-image: url('../images/loader.gif');
   background-repeat: no-repeat;
   z-index: 1050;
}
#txtFindBuddy {
   font-size: 13px !important;
}
