@media (min-width: @screen-lg) {
  #icon-carousel {
    @size: 240px;
    font-size: @size;
    line-height: @size + 35;
    margin-top: @buffer-lg;
  }

  .carousel-control {
    top: @size + 35px;
    .square(40px);
    font-size: 40px;
    line-height: 40px;
    left: 370/2 - 52px;
    &.right {
      right: 370/2 - 52px;
    }
  }

  .jumbotron-ad {
    padding: 50px 0;
    h1 {
      margin-top: 25px;
      font-size: 90px;
    }
    p {
      font-size: 28px;
      margin: 35px 0 20px;
    }
  }

  .jumbotron-carousel {
    padding: 50px 0;
    h1 { font-size: 100px; }
    p {
      font-size: 32px;
      margin: 20px 0;
    }
    .btn-large {
      font-size: 30px;
      padding: 21px 35px;
    }
  }

  .stripe-ad .lead { padding-top: 0; }

  .lead {
    font-size: 26px;
    line-height: 36px;
  }

  .fort-awesome {
    .tagline {  }
    .action { width: 18%; }
  }

  .hide-lg { display: none; }
}
